@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2017 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -131,6 +131,37 @@ public:
   unsigned long getColBufEntry( const AGUIXColor &color );
 #endif
 
+    typedef struct _col_values_t {
+        _col_values_t() : red( 0 ),
+                          green( 0 ),
+                          blue( 0 )
+        {}
+        _col_values_t( int r, int g, int b) : red( r ),
+                                              green( g ),
+                                              blue( b )
+        {}
+
+        bool operator==( const _col_values_t &rhs )
+        {
+            if ( red == rhs.red &&
+                 green == rhs.green &&
+                 blue == rhs.blue ) {
+                return true;
+            } else {
+                return false;
+            }
+        }
+        
+        int red, green, blue;
+    } col_values_t;
+
+    col_values_t getColorInfo( const AGUIXColor &color ) const;
+    col_values_t blend( const col_values_t &lhs,
+                        const col_values_t &rhs,
+                        int percentage ) const;
+
+    AGUIXColor getColor( const col_values_t &v );
+
   std::string getClassname() const;
   Atom *getCloseAtom();
   void insertWindow( AWindow *win, bool change_transient = false );
@@ -337,6 +368,10 @@ public:
                     unsigned int mouse_button );
 
     void widgetDestroyed( Widget *w );
+
+    int getCurrentUserColorInstance() const;
+
+    bool isModifierPressed( unsigned int mask );
 private:
   Display *dsp;
   int scr;
@@ -378,23 +413,14 @@ private:
 #ifdef HAVE_XFT
   XftColor m_user_col_buf[256];
   XftColor m_system_col_buf[16];
+    std::vector< XftColor > m_extra_col_buf;
 #else
   unsigned long m_user_col_buf[256];
   unsigned long m_system_col_buf[16];
+    std::vector< unsigned long > m_extra_col_buf;
 #endif
-  int m_user_colors, m_system_colors;
+    int m_user_colors, m_system_colors, m_extra_colors;
 
-  typedef struct _col_values_t {
-      _col_values_t() : red( 0 ),
-                        green( 0 ),
-                        blue( 0 )
-      {}
-      _col_values_t( int r, int g, int b) : red( r ),
-                                            green( g ),
-                                            blue( b )
-      {}
-      int red, green, blue;
-  } col_values_t;
   std::map< AGUIXColor, col_values_t, AGUIXColor::compare_func > m_color_values;
 
   XEvent LastEvent;
@@ -607,6 +633,10 @@ private:
     Cursor m_xcursor_circle;
 
     int m_x_fd;
+
+    int m_user_color_instance;
+
+    unsigned int m_modifier_pressed = 0;
 };
 
 #endif
