@@ -471,6 +471,15 @@ void Button::redraw()
         _aguix->DrawText( dc, font, tstr, dx + icon_width + icon_space, dy, text_color );
     }
 
+    if ( m_strike_out ) {
+        _aguix->setFG( text_color );
+        _aguix->DrawLine( win,
+                          dx,
+                          _h / 2,
+                          dx + strwidth,
+                          _h / 2);
+    }
+
     if ( m_icon ) {
         if ( m_icon_pos == ICON_RIGHT ) {
             m_icon->draw( win,
@@ -504,8 +513,11 @@ void Button::redraw()
     _aguix->setFG( _aguix->getFaceCol_default_bg() );
     _aguix->DrawTriangleFilled( win, px1, py1, _w-1, 0, px3, py3 );
   }
-  
-  _aguix->drawBorder( win, ( state == 0 ) ? false : true, 0, 0, _w, _h, ear_width - 1 );
+
+  if ( ! m_disabled ) {
+      _aguix->drawBorder( win, ( state == 0 ) ? false : true, 0, 0, _w, _h, ear_width - 1 );
+  }
+
   if( showe == true ) {
     _aguix->setFG( _aguix->getFaceCol_3d_dark() );
     _aguix->DrawLine( win, px1, py1, px2, py2 );
@@ -588,12 +600,16 @@ bool Button::handleMessage(XEvent *E,Message *msg)
 
                             agmsg->button.keystate = KEYSTATEMASK( msg->keystate );
 
-                            msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
+                            if ( ! m_disabled ) {
+                                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
+                            } else {
+                                delete agmsg;
+                            }
                             returnvalue=true;
                         }
                     }
                 } else {
-                    if((state!=0)&&(instate!=0)) {
+                    if ( state != 0 && instate != 0 && ! m_disabled ) {
                         AGMessage *agmsg = AGUIX_allocAGMessage();
                         agmsg->type=AG_BUTTONRELEASED;
                         agmsg->button.button=this;
@@ -649,7 +665,12 @@ bool Button::handleMessage(XEvent *E,Message *msg)
                         agmsg->button.button=this;
                         agmsg->button.state=1;
                         agmsg->button.keystate = KEYSTATEMASK( msg->keystate );
-                        msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
+
+                        if ( ! m_disabled ) {
+                            msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
+                        } else {
+                            delete agmsg;
+                        }
                         if(instate!=0) {
                             setState(0);
                             instate=0;
@@ -828,3 +849,23 @@ int Button::getPreferredHeight()
         return font->getCharHeight() + 2 * bw;
     }
 }
+
+void Button::setDisabled( bool nv )
+{
+    m_disabled = nv;
+}
+
+bool Button::getDisabled() const
+{
+    return m_disabled;
+}
+
+void Button::setStrikeOut( bool nv )
+{
+    m_strike_out = nv;
+}
+
+bool Button::getStrikeOut() const
+{
+    return m_strike_out;
+}
