@@ -59,6 +59,8 @@ public:
   void swapRows( int row1, int row2 );
   void setStrikeOut( int row, int field, bool nv );
   bool getStrikeOut( int row, int field ) const;
+  void setStrikeOutStart( int row, int field, size_t nv );
+  size_t getStrikeOutStart( int row, int field ) const;
 
   void setXOffset( int nv, bool no_redraw = false );
   int getMaxTextWidth();
@@ -222,6 +224,9 @@ public:
 
       bool strike_out;
       bool strike_out_set;
+
+      size_t strike_out_start = 0;
+      bool strike_out_start_set = false;
   };
   
   void setOnDemandCallback( std::function< void( FieldListView*,
@@ -286,6 +291,9 @@ protected:
     void setStrikeOut( int field, bool nv );
     bool getStrikeOut( int field ) const;
 
+    void setStrikeOutStart( int field, size_t nv );
+    size_t getStrikeOutStart( int field ) const;
+
     void setHighlightSegments( int field, const std::vector< size_t > &segments );
     const std::vector< size_t > *getHighlightSegments( int field ) const;
     void clearHighlightSegments();
@@ -303,6 +311,7 @@ protected:
     int cur_fields;
     std::string **texts;
     std::vector< bool > m_strike_out;
+    std::vector< size_t > m_strike_out_start;
     std::vector< std::vector< size_t > > *m_highlight_segments;
 
     int fg[4], bg[4];
