@@ -1,6 +1,6 @@
 /* guielement.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -30,6 +30,7 @@
 
 class AGUIX;
 class AWindow;
+class BubbleWindow;
 
 class GUIElement : public Widget {
 public:
@@ -63,6 +64,9 @@ public:
   void connect( CallBack *new_cb );
   void setSendMessage( bool nv );
   bool getSendMessage() const;
+
+  virtual void setBubbleHelpText( const std::string &help_text );
+  virtual void openBubbleHelp();
 protected:
   Window win;
   static const char *type;
@@ -76,6 +80,8 @@ protected:
   int callback( int val );
  private:
   CallBack *cb;
+  std::string m_bubble_help_text;
+  std::weak_ptr< BubbleWindow > m_bubble_help_window;
 };
 
 #endif
