@@ -1,6 +1,6 @@
 /* karteibutton.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2004-2014 Ralf Hoffmann.
+ * Copyright (C) 2004-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -205,8 +205,8 @@ void KarteiButton::redraw()
       if ( run == 0 ) {
 	// left triangle
 	if ( i != act_opt ) {
-          // dark grey
-          _aguix->setFG( usegc, AGUIXColor( 1, AGUIXColor::SYSTEM_COLOR ) );
+        // dark grey
+        _aguix->setFG( usegc, _aguix->getFaces().getAGUIXColor( "tab-inactive-bg" ) );
 
 	  // top part of the triangle is always visible
 	  _aguix->DrawTriangleFilled( win, usegc, sx , sy, sx + dx, sy, sx + dx, 0 );
@@ -217,7 +217,7 @@ void KarteiButton::redraw()
 	    _aguix->DrawTriangleFilled( win, usegc, sx , sy, sx + dx, sy, sx + dx, basey );
 	  }
 	} else if ( i == act_opt ) {
-	  _aguix->setFG( usegc, _aguix->getFaces().getColor( "default-bg" ) );
+            _aguix->setFG( usegc, _aguix->getFaces().getAGUIXColor( "tab-active-bg" ) );
 	  
 	  // for active option overdraw right part of previous option
 	  _aguix->DrawTriangleFilled( win, usegc, basex , basey, sx + dx, basey, sx + dx, 0 );
@@ -236,12 +236,13 @@ void KarteiButton::redraw()
       
       if ( run == 0 ) {
 	if ( i != act_opt ) {
-          // dark grey
-          _aguix->setFG( usegc, AGUIXColor( 1, AGUIXColor::SYSTEM_COLOR ) );
-
-	  // this is the bg of an inactive option
-	  _aguix->FillRectangle( win, usegc, sx + dx, 0, dx2, basey );
-	}
+            // dark grey
+            // this is the bg of an inactive option
+            _aguix->setFG( usegc, _aguix->getFaces().getAGUIXColor( "tab-inactive-bg" ) );
+	} else {
+            _aguix->setFG( usegc, _aguix->getFaces().getAGUIXColor( "tab-active-bg" ) );
+        }
+        _aguix->FillRectangle( win, usegc, sx + dx, 0, dx2, basey + 1 );
       } else {
 	_aguix->DrawLine( win, usegc,
 			  sx + dx, 0,
@@ -259,11 +260,13 @@ void KarteiButton::redraw()
       if ( run == 0 ) {
 	if ( i != act_opt ) {
           // dark grey
-          _aguix->setFG( usegc, AGUIXColor( 1, AGUIXColor::SYSTEM_COLOR ) );
+          _aguix->setFG( usegc, _aguix->getFaces().getAGUIXColor( "tab-inactive-bg" ) );
+        } else {
+          _aguix->setFG( usegc, _aguix->getFaces().getAGUIXColor( "tab-active-bg" ) );
+        }
 
-	  // finally the right triangle
-	  _aguix->DrawTriangleFilled( win, usegc, sx + dx + dx2 , 0, sx + dx + dx2, basey, sx + dx + dx2 + 2 * delx, basey );
-	}
+        // finally the right triangle
+        _aguix->DrawTriangleFilled( win, usegc, sx + dx + dx2 , 0, sx + dx + dx2, basey, sx + dx + dx2 + 2 * delx, basey );
       } else {
           _aguix->setFG( usegc, _aguix->getFaceCol_3d_dark() );
           _aguix->DrawLine( win, usegc,
@@ -277,13 +280,18 @@ void KarteiButton::redraw()
       }
       
       if ( run != 0 ) {
+          AGUIXColor col = _aguix->getFaces().getAGUIXColor( "tab-inactive-fg" );
+          if ( i == act_opt ) {
+              col = _aguix->getFaces().getAGUIXColor( "tab-active-fg" );
+          }
+
           if ( m_shrinker.getVal() != NULL ) {
               std::string current_text = m_shrinker->shrink( tstr, m_width_per_option[i], lencalc );
               _aguix->DrawText( dc, font, current_text.c_str(), sx + dx + delx, 1,
-                                _aguix->getFaceCol_default_fg() );
+                                col );
           } else {
               _aguix->DrawText( dc, font, tstr, sx + dx + delx, 1,
-                                _aguix->getFaceCol_default_fg() );
+                                col );
           }
       }
 
@@ -291,7 +299,7 @@ void KarteiButton::redraw()
 	if ( ( getAcceptFocus() == true ) &&
 	     ( getHasFocus() == true ) &&
 	     ( focusPos == i ) ) {
-	  _aguix->setDottedFG( _aguix->getFaceCol_default_fg() );
+	  _aguix->setDottedFG( _aguix->getFaces().getAGUIXColor( "tab-active-fg" ) );
 	  _aguix->DrawDottedRectangle( win, sx + dx + delx - 2, 1, dx2 - 2 * delx + 4, 1 + ch + 1 );
 	}
       }
