@@ -1,6 +1,6 @@
 /* karteibutton.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2004-2005,2009-2010 Ralf Hoffmann.
+ * Copyright (C) 2004-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -30,9 +30,10 @@ class TextShrinker;
 class KarteiButton:public CycleButton {
 public:
   KarteiButton(AGUIX *aguix,int x,int y,int width,
-	       int fg,int bg,int data);
+               int data);
   KarteiButton(AGUIX *aguix,int x,int y,int width,int height,
-	       int fg,int bg,int data);
+               int data);
+
   ~KarteiButton();
   KarteiButton( const KarteiButton &other );
   KarteiButton &operator=( const KarteiButton &other );
