@@ -1,6 +1,6 @@
 /* lowlevelfunc.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -669,3 +669,38 @@ char *AGUIX_fixBackslashed( const char *str1 )
   }
   return newstr;
 }
+
+std::string AGUIX_catTrustedAndUnTrusted2( const std::string &str1,
+                                           const std::string &str2 )
+{
+    char *tstr = AGUIX_catTrustedAndUnTrusted( str1.c_str(), str2.c_str() );
+
+    if ( ! tstr ) return "";
+    std::string res = tstr;
+    _freesafe( tstr );
+
+    return res;
+}
+
+std::string AGUIX_catQuotedAndUnQuoted2( const std::string &str1,
+                                         const std::string &str2 )
+{
+    char *tstr = AGUIX_catQuotedAndUnQuoted( str1.c_str(), str2.c_str() );
+
+    if ( ! tstr ) return "";
+    std::string res = tstr;
+    _freesafe( tstr );
+
+    return res;
+}
+
+std::string AGUIX_prepareForSingleQuote2( const std::string str )
+{
+    char *tstr = AGUIX_prepareForSingleQuote( str.c_str() );
+
+    if ( ! tstr ) return "";
+    std::string res = tstr;
+    _freesafe( tstr );
+
+    return res;
+}
