@@ -1,6 +1,6 @@
 /* lowlevelfunc.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -52,5 +52,11 @@ char *AGUIX_unquoteString( const char *str1 );
 char *AGUIX_catQuotedAndUnQuoted( const char *str1, const char *str2 );
 char *AGUIX_fixBackslashed( const char *str1 );
 
+std::string AGUIX_catTrustedAndUnTrusted2( const std::string &str1,
+                                           const std::string &str2 );
+std::string AGUIX_catQuotedAndUnQuoted2( const std::string &str1,
+                                         const std::string &str2 );
+std::string AGUIX_prepareForSingleQuote2( const std::string str );
+
 #endif /* LOWLEVELFUNC_H */
 
