@@ -1,6 +1,6 @@
 /* mutex.h
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2006 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2002-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,21 +24,26 @@
 
 #include "aguixdefs.h"
 #include <pthread.h>
+#include <mutex>
 
 class MutEx
 {
-public:
-  MutEx();
-  virtual ~MutEx();
-  MutEx( const MutEx &other );
-  MutEx &operator=( const MutEx &other );
-  virtual void lock();
-  virtual void unlock();
-  virtual bool trylock();
+ public:
+    MutEx();
+    virtual ~MutEx();
+    MutEx( const MutEx &other );
+    MutEx &operator=( const MutEx &other );
+    virtual void lock();
+    virtual void unlock();
+    virtual bool trylock();
  protected:
-  pthread_mutex_t _mutex;
-  pthread_t _owner;
-  int _owncount;
+    // the actual pthread mutex for locking and condvar
+    pthread_mutex_t _mutex;
+
+    // a mutex for the owner data
+    std::mutex m_owner_data_mutex;
+    pthread_t _owner;
+    int _owncount;
 };
 
 #endif
