@@ -930,13 +930,14 @@ bool PopUpMenu::isVisibleEntry( int pos ) const
     return false;
 }
 
-bool PopUpMenu::checkForVisibleEntries( const std::string &filter )
+int PopUpMenu::checkForVisibleEntries( const std::string &filter )
 {
     std::string lower_filter = AGUIXUtils::tolower( filter );
-    
+
+    int pos = 0;
     for ( std::vector<InternPopUpEntry>::iterator it1 = m_entries.begin();
           it1 != m_entries.end();
-          it1++ ) {
+          it1++, pos++ ) {
         std::string lower_name;
         
         switch ( it1->type ) {
@@ -945,7 +946,7 @@ bool PopUpMenu::checkForVisibleEntries( const std::string &filter )
           case EDITABLE:
             lower_name = AGUIXUtils::tolower( it1->name );
             if ( lower_name.find( lower_filter ) != std::string::npos ) {
-                return true;
+                return pos;
             }
             break;
           default:
@@ -953,16 +954,24 @@ bool PopUpMenu::checkForVisibleEntries( const std::string &filter )
         }
     }
     
-    return false;
+    return -1;
 }
 
 void PopUpMenu::addStringToFilter( const char *str )
 {
     std::string temp_filter = m_infix_filter;
     temp_filter += str;
-    
-    if ( checkForVisibleEntries( temp_filter ) == true ) {
+
+    int res = checkForVisibleEntries( temp_filter );
+    if ( res >= 0 ) {
         m_infix_filter = temp_filter;
+
+        if ( m_highlighted_entry < 0 ) {
+            // set highlighted entry even if it is not visible as it
+            // will jump to next visible automatically
+            m_highlighted_entry = res;
+        }
+
         updateInfixFilter();
     }
 }
