@@ -1,6 +1,6 @@
 /* slider.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2009,2012-2013 Ralf Hoffmann.
+ * Copyright (C) 2005-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -160,7 +160,7 @@ void Slider::redraw()
   struct point p[3];
   XPoint arrow1[3], arrow2[3];
   int bw, bgbw;
-  int bg_to_use;
+  AGUIXColor bg_to_use( 0 );
 
   bgbw = 1;
 
@@ -172,9 +172,9 @@ void Slider::redraw()
   bw = 2;
 
   if ( m_bg < 0 ) {
-      bg_to_use = _parent->getBG();
+      bg_to_use = _aguix->getFaces().getAGUIXColor( "slider-bg" );
   } else {
-      bg_to_use = m_bg;
+      bg_to_use = AGUIXColor( m_bg );
   }
   _aguix->SetWindowBG( win, bg_to_use );
   _aguix->ClearWin( win );
@@ -251,7 +251,7 @@ void Slider::redraw()
       _aguix->drawBorder( win, ( bar_dir == 1 ) ? true : false, tx, ty,  ( vertical == true ) ? tw : th, ( vertical == true ) ? tw : th, 0 );
 
       // Left/Up-Arrow
-      _aguix->setFG( _aguix->getFaceCol_default_fg() );
+      _aguix->setFG( _aguix->getFaces().getAGUIXColor( "slider-arrow" ) );
       _aguix->DrawTriangleFilled( win,
                                   arrow1[0].x, arrow1[0].y,
                                   arrow1[1].x, arrow1[1].y,
@@ -261,7 +261,7 @@ void Slider::redraw()
   // middle box
 
   // dark grey
-  _aguix->setFG( AGUIXColor( 1, AGUIXColor::SYSTEM_COLOR ) );
+  _aguix->setFG( _aguix->getFaces().getAGUIXColor( "slider-bg2" ) );
   if ( m_show_arrow_buttons ) {
       _aguix->FillRectangle( win, ( vertical == true ) ? tx : tx + th, ( vertical == true ) ? ty + tw : ty,
                              ( vertical == true ) ? tw : tw -  2 * th, ( vertical == true ) ? th -  2 * tw : th );
@@ -314,7 +314,7 @@ void Slider::redraw()
       _aguix->drawBorder( win, ( bar_dir == 2 ) ? true : false, p[0].x, p[0].y, ( vertical == true ) ? tw : th, ( vertical == true ) ? tw : th, 0 );
 
       // Right-Arrow
-      _aguix->setFG( _aguix->getFaceCol_default_fg() );
+      _aguix->setFG( _aguix->getFaces().getAGUIXColor( "slider-arrow" ) );
       _aguix->DrawTriangleFilled( win,
                                   arrow2[0].x, arrow2[0].y,
                                   arrow2[1].x, arrow2[1].y,
