@@ -1,6 +1,6 @@
 /* solidbutton.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -33,6 +33,24 @@ public:
          const char *text,int fg,int bg,bool state);
   SolidButton(class AGUIX *aguix,int x,int y,int width,int height,
          const char *text,int fg,int bg,bool state);
+
+  SolidButton(class AGUIX *aguix,int x,int y,
+         const char *text,bool state);
+  SolidButton(class AGUIX *aguix,int x,int y,int width,
+         const char *text,bool state);
+  SolidButton(class AGUIX *aguix,int x,int y,int width,int height,
+         const char *text,bool state);
+  SolidButton( AGUIX *aguix, int x, int y, int width,
+               const char *text,
+               const std::string &fg_name,
+               const std::string &bg_name,
+               bool state );
+  SolidButton( AGUIX *aguix, int x, int y,
+               const char *text,
+               const std::string &fg_name,
+               const std::string &bg_name,
+               bool state );
+
   virtual ~SolidButton();
   SolidButton( const SolidButton &other );
   SolidButton &operator=( const SolidButton &other );
@@ -59,6 +77,22 @@ private:
   static const char *type;
 
   void prepareBG( bool force = false );
+  void applyFaces();
+
+  void init( AGUIX *aguix, int x, int y,
+             int width, int height,
+             const char *text,
+             int fg, int bg,
+             bool state );
+  void init( AGUIX *aguix, int x, int y,
+             int width,
+             const char *text,
+             int fg, int bg,
+             bool state );
+  void init( AGUIX *aguix, int x, int y,
+             const char *text,
+             int fg, int bg,
+             bool state );
 };
 
 #endif
