@@ -1,6 +1,6 @@
 /* stringgadget.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -208,7 +208,7 @@ void StringGadget::textRedraw()
       if ( active ) {
           text_color = _aguix->getFaces().getColor( "stringgadget-active-fg" );
       } else {
-          text_color = _aguix->getFaceCol_default_fg();
+          text_color = _aguix->getFaces().getColor( "stringgadget-normal-fg" );
       }
 
       _aguix->DrawText( dc, font, use_text + use_xoffset, inner_x + dx, inner_y + dy, text_color );
@@ -256,7 +256,7 @@ void StringGadget::textRedraw()
         if(active==true) {
             text_color = _aguix->getFaces().getColor( "stringgadget-selection-fg" );
         } else {
-            text_color = _aguix->getFaceCol_default_fg();
+            text_color = _aguix->getFaces().getColor( "stringgadget-normal-fg" );
         }
         _aguix->DrawText( dc, font, use_text + minx, inner_x + dx, inner_y + dy, text_color );
     }
@@ -284,7 +284,7 @@ void StringGadget::textRedraw()
       if ( active ) {
           text_color = _aguix->getFaces().getColor( "stringgadget-active-fg" );
       } else {
-          text_color = _aguix->getFaceCol_default_fg();
+          text_color = _aguix->getFaces().getColor( "stringgadget-normal-fg" );
       }
 
       _aguix->DrawText( dc, font, use_text + first_vis_char, inner_x + dx, inner_y + dy, text_color );
@@ -1072,7 +1072,7 @@ int StringGadget::clearTextBG()
   if ( active == true ) {
       newbg = _aguix->getFaces().getColor( "stringgadget-active-bg" );
   } else {
-      newbg = _aguix->getFaceCol_default_bg();
+      newbg = _aguix->getFaces().getColor( "stringgadget-normal-bg" );
   }
   
   _aguix->setFG( newbg );
