@@ -114,7 +114,7 @@ class TextStorageString : public TextStorage
     void setConvertMode( enum text_storage_converion convert );
  private:
   void initBuffer( const std::string &content, int line_limit_width = -1 );
-  unsigned int getTokenLen( unsigned int start_offset );
+    unsigned int getTokenLen( unsigned int start_offset, int limit );
     std::string getReplacementString( unsigned char ch, size_t column ) const;
   
     void convertRawData();
