@@ -1,6 +1,6 @@
 /* textview.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2018 Ralf Hoffmann.
+ * Copyright (C) 2005-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -135,9 +135,6 @@ void TextView::createContainer()
   
   cont->resize( _w, _h );
   cont->rearrange();
-
-  hbar->setBG( _colors.getBackground() );
-  vbar->setBG( _colors.getBackground() );
 }
 
 void TextView::boxRedraw()
@@ -886,13 +883,6 @@ void TextView::setColors( const ColorDef &col )
 {
     _colors = col;
     setBG( _colors.getBackground() );
-
-    if ( hbar ) {
-        hbar->setBG( _colors.getBackground() );
-    }
-    if ( vbar ) {
-        vbar->setBG( _colors.getBackground() );
-    }
 }
 
 TextView::ColorDef TextView::getColors() const
