@@ -112,7 +112,7 @@ public:
   void clearSelection();
     void selectAll();
 
-  void sizeChanged( int width, int height );
+  void sizeChanged( int width, int height, bool explicit_resize );
 
   void makeSelectionVisible();
 
