@@ -577,4 +577,79 @@ namespace AGUIXUtils
 
         return res;
     }
+
+    int escape_characters( const std::string &input,
+                           std::string &output,
+                           escape_type_t type )
+    {
+        if ( type != ESCAPE_JSON ) return -EINVAL;
+
+        output.clear();
+
+        // escape ", \, newline, cr, tab
+        for ( auto &ch : input ) {
+            switch ( ch ) {
+                case '"':
+                case '\\':
+                    output += "\\";
+                    output += ch;
+                    break;
+                case '\n':
+                    output += "\\n";
+                    break;
+                case '\r':
+                    output += "\\r";
+                    break;
+                case '\t':
+                    output += "\\t";
+                    break;
+                default:
+                    output += ch;
+                    break;
+            }
+        }
+
+        return 0;
+    }
+
+    int unescape_characters( const std::string &input,
+                             std::string &output,
+                             escape_type_t type )
+    {
+        if ( type != ESCAPE_JSON ) return -EINVAL;
+
+        output.clear();
+
+        for ( size_t pos = 0; pos < input.length(); pos++ ) {
+            char ch = input[pos];
+
+            if ( ch != '\\' ) {
+                output += ch;
+                continue;
+            }
+
+            if ( pos + 1 >= input.length() ) {
+                fprintf( stderr, "Missing character at end of string: %s\n", input.c_str() );
+                return -EINVAL;
+            }
+
+            char ch2 = input[pos + 1];
+
+            if ( ch2 == '"' || ch2 == '\\' ) {
+                output += ch2;
+            } else if ( ch2 == 'n' ) {
+                output += '\n';
+            } else if ( ch2 == 'r' ) {
+                output += '\r';
+            } else if ( ch2 == 't' ) {
+                output += '\t';
+            } else {
+                fprintf( stderr, "Invalid escaped character %d (%c)\n", ch2, ch2 );
+                return -EINVAL;
+            }
+            pos++;
+        }
+
+        return 0;
+    }
 }
