@@ -122,6 +122,17 @@ namespace AGUIXUtils
 
     std::string escape_uri( const std::string &uri );
     std::string unescape_uri( const std::string &uri );
+
+    typedef enum {
+                  ESCAPE_JSON
+    } escape_type_t;
+    
+    int escape_characters( const std::string &input,
+                           std::string &output,
+                           escape_type_t type );
+    int unescape_characters( const std::string &input,
+                             std::string &output,
+                             escape_type_t type );
 }
 
 #define TIMEMEASURE_T struct timeval
