@@ -142,7 +142,7 @@ bool ChangeLabelOp::save( Datei *fh )
 
 const char *ChangeLabelOp::getDescription()
 {
-    return catalog.getLocaleCom( 55 );
+    return catalog.getLocale( 1296 );
 }
 
 int ChangeLabelOp::configure()
@@ -156,8 +156,8 @@ int ChangeLabelOp::configure()
     int endmode = -1;
     char *tstr;
     
-    tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( catalog.getLocaleCom( 55 ) ) + 1 );
-    sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 55 ) );
+    tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( getDescription() ) + 1 );
+    sprintf( tstr, catalog.getLocale( 293 ), getDescription() );
     win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
     win->create();
     _freesafe( tstr );
