@@ -87,7 +87,7 @@ ChangeSymlinkOp::run( WPUContext *wpu, ActionMessage *msg )
 const char *
 ChangeSymlinkOp::getDescription()
 {
-  return catalog.getLocaleCom(37);
+  return catalog.getLocale(1278);
 }
 
 int
