@@ -254,7 +254,7 @@ int ChTimeCore::requestNewTime( const FileEntry &fe,
     time_t current_mod_time = ( fe.isLink == true &&
                                 fe.isCorrupt == false ) ? fe.dlastmod() : fe.lastmod();
 
-    win = new AWindow( m_aguix, 10, 10, 10, 10, catalog.getLocaleCom( 63 ), AWindow::AWINDOW_DIALOG );
+    win = new AWindow( m_aguix, 10, 10, 10, 10, catalog.getLocale( 1304 ), AWindow::AWINDOW_DIALOG );
     win->create();
     
     AContainer *ac1 = win->setContainer( new AContainer( win, 1, 4 ), true );
