@@ -96,7 +96,7 @@ ClipboardOp::save(Datei *fh)
 const char *
 ClipboardOp::getDescription()
 {
-    return catalog.getLocaleCom( 61 );
+    return catalog.getLocale( 1302 );
 }
 
 int
@@ -124,8 +124,8 @@ ClipboardOp::doconfigure(int mode)
         AContainer::ACONT_MAXH +
         AContainer::ACONT_MAXW;
   
-    tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( catalog.getLocaleCom( 61 ) ) + 1 );
-    sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 61 ) );
+    tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( getDescription() ) + 1 );
+    sprintf( tstr, catalog.getLocale( 293 ), getDescription() );
     win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
     win->create();
     _freesafe( tstr );
