@@ -68,7 +68,7 @@ int CommandMenuOp::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *CommandMenuOp::getDescription()
 {
-    return catalog.getLocaleCom( 62 );
+    return catalog.getLocale( 1303 );
 }
 
 int CommandMenuOp::configure()
