@@ -1,6 +1,6 @@
 /* configtokens.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2003-2019 Ralf Hoffmann.
+ * Copyright (C) 2003-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -450,7 +450,8 @@ struct mytoken tokenlist[]={
   { EXTENSION_WCP, "extension" },
   { TERMINAL_RETURNS_EARLY_WCP, "terminalreturnsearly" },
   { DIRECTORYPRESETS_WCP, "directorypresets" },
-  { DIRECTORYPRESET_WCP, "directorypreset" }
+  { DIRECTORYPRESET_WCP, "directorypreset" },
+  { HELPOP_WCP, "helpop" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
