@@ -1,6 +1,6 @@
 /* copycore.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013-2015 Ralf Hoffmann.
+ * Copyright (C) 2013-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -32,6 +32,7 @@
 #include <chrono>
 #include <ratio>
 #include "nwc_path.hh"
+#include "nwc_os.hh"
 
 CopyCore::CopyCore( std::shared_ptr< struct copyorder > co ) :
     m_copyorder( co ),
@@ -1672,16 +1673,19 @@ void CopyCore::pushForPostDelete( const FileEntry *fe )
 }
 
 void CopyCore::registerFEToCopy( const FileEntry &fe,
-                                 int row )
+                                 int row,
+                                 const std::vector< NWC::OS::deep_dir_info > &file_base_segments )
 {
-    m_copy_list.push_back( copy_base_entry( fe, row ) );
+    m_copy_list.push_back( copy_base_entry( fe, row, file_base_segments ) );
 }
 
 CopyCore::copy_base_entry::copy_base_entry( const FileEntry &fe,
-                                            int row ) :
+                                            int row,
+                                            const std::vector< NWC::OS::deep_dir_info > &file_base_segments ) :
     m_row( row ),
     m_cod( NULL ),
-    m_fe( fe )
+    m_fe( fe ),
+    m_file_base_segments( file_base_segments )
 {
 }
 
@@ -1779,6 +1783,43 @@ int CopyCore::executeCopy()
     return 0;
 }
 
+int CopyCore::prepare_destination_dir( copy_base_entry &cbe,
+                                       std::string &destdir,
+                                       bool post_run )
+{
+    destdir = m_copyorder->destdir;
+    int res = 0;
+
+    if ( m_copyorder->vdir_preserve_dir_structure &&
+         ! cbe.get_file_base_segments().empty() ) {
+
+        if ( post_run == false ||
+             m_copyorder->preserve_attr == true ) {
+            res = NWC::OS::make_dirs( destdir,
+                                      cbe.get_file_base_segments(),
+                                      post_run );
+
+            if ( res != 0 ) {
+                if ( m_copyorder->cowin != NULL ) m_copyorder->cowin->stoptimer();
+                auto text = AGUIXUtils::formatStringToString( catalog.getLocale( 1210 ), destdir.c_str() );
+                auto button = std::string( catalog.getLocale( 225 ) ) + "|" + catalog.getLocale( 8 );
+                auto erg = m_copyorder->cowin->request( catalog.getLocale( 347 ), text.c_str(), button.c_str() );
+                if ( erg == 0 ) {
+                } else {
+                    m_cancel = true;
+                }
+                if ( m_copyorder->cowin != NULL ) m_copyorder->cowin->conttimer();
+            }
+        }
+
+        for ( auto &s : cbe.get_file_base_segments() ) {
+            destdir = NWC::Path::join( destdir, s.get_segment_name() );
+        }
+    }
+
+    return res;
+}
+
 int CopyCore::executeCopyThread()
 {
     for ( auto &cbe : m_copy_list ) {
@@ -1805,12 +1846,23 @@ int CopyCore::executeCopyThread()
         if ( tcod != NULL ) {
             nm_copy_t ce1;
             std::string target_fullname;
+            std::string destdir;
 
-            ce1 = copydir( &cbe.entry(), tcod, true, m_copyorder->destdir.c_str(), &target_fullname );
-            if ( ce1 == NM_COPY_OK || ce1 == NM_COPY_NEED_DELETE ) {
-                // success
-            } else if ( ce1 == NM_COPY_CANCEL ) {
-                m_cancel = true;
+            if ( prepare_destination_dir( cbe, destdir, false ) == 0 ) {
+                ce1 = copydir( &cbe.entry(), tcod, true, destdir.c_str(), &target_fullname );
+                if ( ce1 == NM_COPY_OK || ce1 == NM_COPY_NEED_DELETE ) {
+                    // success
+                } else if ( ce1 == NM_COPY_CANCEL ) {
+                    m_cancel = true;
+                }
+
+                prepare_destination_dir( cbe, destdir, true );
+            } else {
+                if ( m_cancel ) {
+                    ce1 = NM_COPY_CANCEL;
+                } else {
+                    ce1 = NM_COPY_SKIP;
+                }
             }
 
             if ( m_post_cb ) {
@@ -1823,13 +1875,24 @@ int CopyCore::executeCopyThread()
         } else {
             nm_copy_t ce1;
             std::string target_fullname;
+            std::string destdir;
 
-            ce1 = copyfile( &cbe.entry(), true, m_copyorder->destdir.c_str(), &target_fullname );
+            if ( prepare_destination_dir( cbe, destdir, false ) == 0 ) {
+                ce1 = copyfile( &cbe.entry(), true, destdir.c_str(), &target_fullname );
 
-            if ( ce1 == NM_COPY_OK || ce1 == NM_COPY_NEED_DELETE ) {
-                // success
-            } else if ( ce1 == NM_COPY_CANCEL ) {
-                m_cancel = true;
+                if ( ce1 == NM_COPY_OK || ce1 == NM_COPY_NEED_DELETE ) {
+                    // success
+                } else if ( ce1 == NM_COPY_CANCEL ) {
+                    m_cancel = true;
+                }
+
+                prepare_destination_dir( cbe, destdir, true );
+            } else {
+                if ( m_cancel ) {
+                    ce1 = NM_COPY_CANCEL;
+                } else {
+                    ce1 = NM_COPY_SKIP;
+                }
             }
 
             if ( m_post_cb ) {
