@@ -170,7 +170,7 @@ CopyOp::save(Datei *fh)
 const char *
 CopyOp::getDescription()
 {
-  return catalog.getLocaleCom(8);
+  return catalog.getLocale(1249);
 }
 
 int
@@ -422,8 +422,8 @@ CopyOp::doconfigure(int mode)
   
   req=new Requester(aguix);
 
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(8))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(8));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
@@ -432,7 +432,7 @@ CopyOp::doconfigure(int mode)
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocaleCom( 8 ) ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, getDescription() ), 0, 0, cincwnr );
 
   fscb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( follow_symlinks == true ) ? 1 : 0,
 						    catalog.getLocale( 298 ), LABEL_RIGHT, 0 ), 0, 1, cincwnr );
