@@ -1,6 +1,6 @@
 /* copyop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -54,6 +54,7 @@ public:
   void setRequestFlags(bool);
   void setOverwrite(overwrite_t);
   void setPreserveAttr(bool);
+  void setVdirPreserveDirStructure(bool);
 
   typedef enum { COPYOP_ADJUST_SYMLINK_NEVER,
                  COPYOP_ADJUST_SYMLINK_OUTSIDE,
@@ -62,6 +63,8 @@ public:
 
   void setAdjustRelativeSymlinks( adjust_relative_symlinks_t nv );
   void setEnsureFilePermissions( const CopyParams::EnsureFilePermissions &nv );
+  bool isInteractiveRun() const;
+  void setInteractiveRun();
 protected:
   static const char *name;
   // Infos to save
@@ -71,6 +74,7 @@ protected:
   bool same_dir;
   bool request_dest;
   bool preserve_attr;
+  bool vdir_preserve_dir_structure;
   adjust_relative_symlinks_t adjust_relative_symlinks;
   CopyParams::EnsureFilePermissions ensure_file_permissions;
   bool request_flags;
@@ -87,6 +91,7 @@ protected:
   bool tsame_dir;
   bool trequest_dest;
   bool tpreserve_attr;
+  bool tvdir_preserve_dir_structure;
   adjust_relative_symlinks_t tadjust_relative_symlinks;
   CopyParams::EnsureFilePermissions tensure_file_permissions;
   overwrite_t toverwrite;
