@@ -1,6 +1,6 @@
 /* datei.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -1327,23 +1327,3 @@ size_t Datei::read( char *buffer, size_t len )
 CopyfileProgressCallback::~CopyfileProgressCallback()
 {
 }
-
-bool Datei::lock()
-{
-    if ( fd < 0 ) return false;
-
-#ifdef HAVE_LOCKF
-    if ( lockf( fd, F_LOCK, 0 ) == 0 ) {
-        return true;
-    }
-#endif
-
-    return false;
-}
-
-void Datei::unlock()
-{
-#ifdef HAVE_LOCKF
-    int res __attribute__((unused)) = lockf( fd, F_ULOCK, 0 );
-#endif
-}
