@@ -1,6 +1,6 @@
 /* datei.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2016 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -109,9 +109,6 @@ public:
   void configCloseSection();
 
   size_t read( char *buffer, size_t len );
-
-    bool lock();
-    void unlock();
 private:
   int fd;
   long error;
