@@ -340,3 +340,8 @@ bool DeepPathStore::removeEntry( const std::string &path )
 
     return true;
 }
+
+bool DeepPathStore::empty() const
+{
+    return m_root.get_children().empty();
+}
