@@ -88,7 +88,7 @@ DeleteOp::run( WPUContext *wpu, ActionMessage *msg )
 const char *
 DeleteOp::getDescription()
 {
-  return catalog.getLocaleCom(25);
+  return catalog.getLocale(1266);
 }
 
 int
@@ -149,8 +149,8 @@ int DeleteOp::configure()
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
 
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(25))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(25));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
@@ -256,7 +256,7 @@ DeleteOpWin::open()
   close();
   w=400;
   h=10;
-  window = new AWindow( aguix, 10, 10, w, h, catalog.getLocaleCom( 25 ),
+  window = new AWindow( aguix, 10, 10, w, h, catalog.getLocale( 1266 ),
                         AWindow::AWINDOW_DIALOG );
   window->create();
   tx=5;
