@@ -1,6 +1,6 @@
 /* dirbookmarkeditui.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2008,2013 Ralf Hoffmann.
+ * Copyright (C) 2008-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -48,7 +48,7 @@ DirBookmarkEditUI::DirBookmarkEditUI( AGUIX &aguix, BookmarkDBProxy &data,
     m_win = std::unique_ptr<AWindow>( new AWindow( &m_aguix,
                                                    0, 0,
                                                    400, 400,
-                                                   0, catalog.getLocale( 805 ),
+                                                   catalog.getLocale( 805 ),
                                                    AWindow::AWINDOW_DIALOG ) );
     m_win->create();
 
@@ -59,7 +59,7 @@ DirBookmarkEditUI::DirBookmarkEditUI( AGUIX &aguix, BookmarkDBProxy &data,
     co1_1->setMinSpace( 5 );
     co1_1->setMaxSpace( 5 );
     co1_1->setBorderWidth( 0 );
-    co1_1->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 806 ), 1 ),
+    co1_1->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 806 ) ),
                 0, 0, AContainer::CO_FIX );
     m_name_sg = (StringGadget*)co1_1->add( new StringGadget(  &m_aguix,
                                                               0, 0, 100,
@@ -70,7 +70,7 @@ DirBookmarkEditUI::DirBookmarkEditUI( AGUIX &aguix, BookmarkDBProxy &data,
     co1_2->setMinSpace( 5 );
     co1_2->setMaxSpace( 5 );
     co1_2->setBorderWidth( 0 );
-    co1_2->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 807 ), 1 ),
+    co1_2->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 807 ) ),
                 0, 0, AContainer::CO_FIX );
     m_alias_sg = (StringGadget*)co1_2->add( new StringGadget(  &m_aguix,
                                                                0, 0, 100,
@@ -86,14 +86,14 @@ DirBookmarkEditUI::DirBookmarkEditUI( AGUIX &aguix, BookmarkDBProxy &data,
                                                                   m_entry.getUseParent(),
                                                                   catalog.getLocale( 808 ),
                                                                   LABEL_LEFT,
-                                                                  1, 0 ),
+                                                                  0 ),
                                                 0, 0, AContainer::CO_INCWNR );
 
     AContainer *co1_5 = co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 3 );
     co1_5->setMinSpace( 5 );
     co1_5->setMaxSpace( 5 );
     co1_5->setBorderWidth( 0 );
-    co1_5->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 831 ), 1 ),
+    co1_5->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 831 ) ),
                 0, 0, AContainer::CO_INCH + AContainer::ACONT_NORESIZE );
 
     AContainer *co1_5_1 = co1_5->add( new AContainer( m_win.get(), 1, 2 ), 1, 0 );
@@ -140,16 +140,12 @@ DirBookmarkEditUI::DirBookmarkEditUI( AGUIX &aguix, BookmarkDBProxy &data,
                                              0,
                                              0,
                                              catalog.getLocale( 11 ),
-                                             1,
-                                             0,
                                              0 ), 0, 0, AContainer::CO_FIX );
 
     m_cancelb = (Button*)co1_4->add( new Button( &m_aguix,
                                                  0,
                                                  0,
                                                  catalog.getLocale( 8 ),
-                                                 1,
-                                                 0,
                                                  0 ), 1, 0, AContainer::CO_FIX );
 
     m_win->contMaximize( true );
