@@ -77,7 +77,9 @@ int DirBookmarkOp::run( WPUContext *wpu, ActionMessage *msg )
 
     BookmarkDBProxy &bookmarks = Worker::getBookmarkDBInstance();
     bookmarks.read();
-    DirBookmarkUI ui( *Worker::getAGUIX(), bookmarks );
+    DirBookmarkUI ui( *msg->getWorker(),
+                      *Worker::getAGUIX(),
+                      bookmarks );
 
     lm1 = l1->getActiveMode();
     if ( lm1 != NULL ) {
