@@ -1,6 +1,6 @@
 /* dirbookmarkui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007-2014 Ralf Hoffmann.
+ * Copyright (C) 2007-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -38,8 +38,11 @@
 #include "worker.h"
 #include "stringmatcher_flexibleregex.hh"
 
-DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDBProxy &data  ) : m_aguix( aguix ),
-                                                                       m_data( data )
+DirBookmarkUI::DirBookmarkUI( Worker &worker,
+                              AGUIX &aguix,
+                              BookmarkDBProxy &data  ) : m_worker( worker ),
+                                                         m_aguix( aguix ),
+                                                         m_data( data )
 {
     m_filtered_data = std::unique_ptr<BookmarkDBFilter>( new BookmarkDBFilter( data ) );
 
@@ -81,19 +84,28 @@ DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDBProxy &data  ) : m_aguix(
                                                                      0, 0, 
                                                                      400, 300, 0 ),
                                                   0, 2, AContainer::CO_MIN ) );
-    m_lv->setNrOfFields( 5 );
+    m_lv->setNrOfFields( 4 );
+    m_lv->setGlobalFieldSpace( 5 );
     m_lv->setShowHeader( true );
     m_lv->setFieldText( 0, catalog.getLocale( 809 ) );
-    m_lv->setFieldWidth( 1, 5 );
+    m_lv->setFieldSpace( 0, 0 );
+    m_lv->setFieldSpace( 1, 0 );
     m_lv->setFieldTextMerged( 0, true );
+    m_lv->setFieldWidth( 0, m_aguix.getTextWidth( "?" ) );
     m_lv->setFieldText( 2, catalog.getLocale( 810 ) );
-    m_lv->setFieldWidth( 3, 5 );
-    m_lv->setFieldTextMerged( 2, true );
-    m_lv->setFieldText( 4, catalog.getLocale( 823 ) );
+    m_lv->setFieldText( 3, catalog.getLocale( 823 ) );
     m_lv->setHBarState( 2 );
     m_lv->setVBarState( 2 );
     m_lv->setAcceptFocus( true );
     m_lv->setDisplayFocus( true );
+    m_lv->setOnDemandCallback( [this]( FieldListView *lv,
+                                       int row,
+                                       int field,
+                                       struct FieldListView::on_demand_data &data )
+                               {
+                                   updateLVData( row, field, data );
+                               } );
+
 
     AContainer *co1_4 = m_co1->add( new AContainer( m_win.get(), 3, 1 ), 0, 3 );
     co1_4->setMinSpace( 5 );
@@ -172,7 +184,7 @@ int DirBookmarkUI::mainLoop()
 
         for ( int row = 0;; row++ ) {
             if ( m_lv->isValidRow( row ) == false ) break;
-            if ( m_lv->getText( row, 0 ) == start_entry ) {
+            if ( m_lv->getText( row, 1 ) == start_entry ) {
                 m_lv->setActiveRow( row );
                 m_lv->showActive();
                 found = true;
@@ -190,7 +202,7 @@ int DirBookmarkUI::mainLoop()
             for ( int row = 0;; row++ ) {
                 if ( m_lv->isValidRow( row ) == false ) break;
 
-                const std::string &entry_text = m_lv->getText( row, 0 );
+                const std::string &entry_text = m_lv->getText( row, 1 );
 
                 if ( entry_text.length() > start_entry.length() ) {
                     if ( entry_text.compare( 0,
@@ -221,7 +233,7 @@ int DirBookmarkUI::mainLoop()
             for ( int row = 0;; row++ ) {
                 if ( m_lv->isValidRow( row ) == false ) break;
 
-                const std::string &entry_text = m_lv->getText( row, 0 );
+                const std::string &entry_text = m_lv->getText( row, 1 );
 
                 if ( entry_text.length() < start_entry.length() ) {
                     if ( start_entry.compare( 0,
@@ -245,7 +257,14 @@ int DirBookmarkUI::mainLoop()
     }
 
     for ( ; endmode == 0; ) {
-        msg = m_aguix.WaitMessage( NULL );
+        if ( m_existence_tests.empty() ) {
+            msg = m_aguix.WaitMessage( NULL );
+        } else {
+            msg = m_aguix.GetMessage( NULL );
+        }
+
+        checkExistResults();
+
         if ( msg != NULL ) {
             switch ( msg->type ) {
               case AG_CLOSEWINDOW:
@@ -398,6 +417,17 @@ int DirBookmarkUI::mainLoop()
                     break;
             }
             m_aguix.ReplyMessage( msg );
+
+            if ( endmode == 1 ) {
+                int row = m_lv->getActiveRow();
+                if ( m_lv->isValidRow( row ) ) {
+                    std::string path = m_lv->getText( row, 1 );
+
+                    if ( ! NWC::FSEntry( path ).entryExists() ) {
+                        endmode = 0;
+                    }
+                }
+            }
         }
     }
 
@@ -420,6 +450,8 @@ int DirBookmarkUI::mainLoop()
 
     m_win->hide();
     
+    moveTests();
+
     return endmode;
 }
 
@@ -437,14 +469,19 @@ void DirBookmarkUI::showData( const std::string &cat )
 
     m_lv->setSize( 0 );
     
+    // invalidate running futures
+    for ( auto &e : m_existence_tests ) {
+        std::get<2>( e ) = false;
+    }
+
     std::list<BookmarkDBEntry> e = m_filtered_data->getEntries( cat );
     for ( std::list<BookmarkDBEntry>::iterator it1 = e.begin();
           it1 != e.end();
           it1++ ) {
         int row = m_lv->addRow();
-        m_lv->setText( row, 0, it1->getName() );
+        m_lv->setText( row, 1, it1->getName() );
         m_lv->setText( row, 2, it1->getAlias() );
-        m_lv->setText( row, 4, it1->getCategory() );
+        m_lv->setText( row, 3, it1->getCategory() );
         m_lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
         
         if ( row == act_row )
@@ -454,7 +491,7 @@ void DirBookmarkUI::showData( const std::string &cat )
             std::vector< size_t > segments = matcher.getMatchSegments( it1->getName() );
 
             if ( segments.size() > 1 ) {
-                m_lv->setHighlightSegments( row, 0, segments );
+                m_lv->setHighlightSegments( row, 1, segments );
             }
         }
     }
@@ -608,10 +645,120 @@ void DirBookmarkUI::highlightBestHit( class PrefixDB &pdb )
 
     for ( int row = 0;; row++ ) {
 	if ( m_lv->isValidRow( row ) == false ) break;
-	if ( m_lv->getText( row, 0 ) == best_hit ) {
+	if ( m_lv->getText( row, 1 ) == best_hit ) {
 	    m_lv->setActiveRow( row );
 	    m_lv->showActive();
 	    break;
 	}
     }
 }
+
+void DirBookmarkUI::updateLVData( int row, int field,
+                                  struct FieldListView::on_demand_data &data )
+{
+    if ( field == 0 ) {
+        std::string path = m_lv->getText( row, 1 );
+
+        if ( m_existence_results.count( path ) == 0 ) {
+            auto f = std::async( std::launch::async,
+                                 [path] {
+                                     return ExistenceTest::checkPathExistence( path );
+                                 } );
+            m_existence_tests.push_back( std::make_tuple( std::move( f ), row, true ) );
+
+            data.text = "?";
+            data.text_set = true;
+        } else {
+            auto &res = m_existence_results.at( path );
+
+            if ( res.exists == ExistenceTest::EXISTS_YES ) {
+                data.text = "";
+                data.text_set = true;
+            } else if ( res.exists == ExistenceTest::EXISTS_NO ) {
+                data.text = "";
+                data.text_set = true;
+            }
+        }
+    } else if ( field == 1 ) {
+        std::string path = m_lv->getText( row, 1 );
+
+        if ( m_existence_results.count( path ) > 0 ) {
+            auto &res = m_existence_results.at( path );
+
+            if ( res.exists == ExistenceTest::EXISTS_NO ) {
+                data.strike_out = true;
+                data.strike_out_set = true;
+                data.strike_out_start = res.path_length + 1;
+                data.strike_out_start_set = true;
+            }
+
+            data.done = true;
+        }
+    }
+}
+
+void DirBookmarkUI::moveTests()
+{
+    for ( auto it = m_existence_tests.begin();
+          it != m_existence_tests.end();
+          ) {
+        std::future_status status = std::get<0>( *it ).wait_for( std::chrono::duration<int>::zero() );
+
+        auto next_it = it;
+        next_it++;
+
+        if ( status != std::future_status::ready ) {
+            auto f = std::move( std::get<0>( *it ) );
+
+            m_worker.enqueueFuture( std::move( f ) );
+        }
+
+        m_existence_tests.erase( it );
+        it = next_it;
+    }
+}
+
+void DirBookmarkUI::checkExistResults()
+{
+    if ( m_existence_tests.empty() ) {
+        return;
+    }
+
+    bool update_lv = false;
+
+    for ( auto it = m_existence_tests.begin();
+          it != m_existence_tests.end();
+          ) {
+        std::future_status status = std::get<0>( *it ).wait_for(std::chrono::duration<int>::zero());
+
+        if ( status == std::future_status::ready ) {
+            ExistenceTest::existence_state_t res = std::get<0>( *it ).get();
+
+            if ( std::get<2>( *it ) == true ) {
+                int row = std::get<1>( *it );
+
+                if ( m_lv->isValidRow( row ) ) {
+                    std::string path = m_lv->getText( row, 1 );
+
+                    m_existence_results[ path ] = res;
+
+                    m_lv->clearOnDemandDataAvailableFlag( row );
+                    update_lv = true;
+                }
+            }
+
+            auto next_it = it;
+            next_it++;
+
+            m_existence_tests.erase( it );
+
+            it = next_it;
+        } else {
+            it++;
+        }
+    }
+
+    if ( update_lv ) {
+        m_lv->redraw();
+    }
+}
