@@ -166,6 +166,8 @@ void DMCacheEntryNWC::applyOldSettings( std::vector< NWCEntrySelectionState > &n
                     }
                     new_es.setColor( old_es_it->getColor() );
                     new_es.setBookmarkInfo( old_es_it->getBookmarkInfo() );
+                    new_es.setFiletypeFileOutput( old_es_it->getFiletypeFileOutput() );
+                    new_es.setMimeType( old_es_it->getMimeType() );
 
                     NWC::Dir *old_dir = dynamic_cast< NWC::Dir * >( old_fse );
                     NWC::Dir *new_dir = dynamic_cast< NWC::Dir * >( new_fse );
