@@ -1,6 +1,6 @@
 /* dnd.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -34,32 +34,36 @@ class FileEntry;
 class DNDMsg
 {
 public:
-  DNDMsg(Worker *worker);
-  DNDMsg(Worker *worker,AGDNDSTART s,AGDNDEND e);
-  ~DNDMsg();
-  DNDMsg( const DNDMsg &other );
-  DNDMsg &operator=( const DNDMsg &other );
+    DNDMsg( Worker *worker );
+    ~DNDMsg();
+    DNDMsg( const DNDMsg &other );
+    DNDMsg &operator=( const DNDMsg &other );
 
-  const FileEntry *getFE() const;
+    const FileEntry *getFE() const;
     std::string getDestDir() const;
-  Lister *getDestLister() const;
-  ListerMode *getDestMode() const;
-  Lister *getSourceLister() const;
-  ListerMode *getSourceMode() const;
+    Lister *getDestLister() const;
+    ListerMode *getDestMode() const;
+    Lister *getSourceLister() const;
+    ListerMode *getSourceMode() const;
 
-  void setStart(AGDNDSTART*s);
-  void setEnd(AGDNDEND*e);
-  const AGDNDSTART *getStart();
-  const AGDNDEND *getEnd();
+    void setEnd( AGDNDEND *e );
 
+    int getValue() const;
+    class FieldLVRowData *getRowDataP() const;
+    std::string *getExternalData() const;
+    Widget *getSourceWidget() const;
+    Widget *getDestWidget() const;
 protected:
-  AGDNDSTART start;
-  AGDNDEND end;
+    int value;
+    class FieldLVRowData *rowDataP;
+    std::string *external_data;
   
-  Lister *sl,*el;
-  ListerMode *slm,*elm;
+    Lister *sl, *el;
+    ListerMode *slm, *elm;
+    Widget *source_widget;
+    Widget *dest_widget;
   
-  Worker *worker;
+    Worker *worker;
 };
 
 #endif
