@@ -97,7 +97,7 @@ EnterPathOp::save(Datei *fh)
 const char *
 EnterPathOp::getDescription()
 {
-  return catalog.getLocaleCom(34);
+  return catalog.getLocale(1275);
 }
 
 void
@@ -150,8 +150,8 @@ EnterPathOp::configure()
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
   
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(34))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(34));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
