@@ -1,6 +1,6 @@
 /* execlass.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2017 Ralf Hoffmann.
+ * Copyright (C) 2002-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,10 +31,9 @@
 #include <sstream>
 
 /* THREADSAFE */
-ExeClass::ExeClass( execlass_execute_t exetype, Worker *w )
+ExeClass::ExeClass( Worker *w )
 {
   worker = w;
-  type = exetype;
   tmpfile = Datei::createTMPName();
   tmpoutput = Datei::createTMPName();
   tmperror = Datei::createTMPName();
@@ -125,11 +124,7 @@ void ExeClass::addCommand( const char *format, ... )
     _freesafe( tstr );
     if ( string1.length() > 0 ) {
       if ( fprintf( fp, "%s", string1.c_str() ) < 0 ) error++;
-      if ( type == EXECUTE_SHOW_OUTPUT ) {
-        if ( fprintf( fp, " >>%s\n", tmpoutput ) < 0 ) error++;
-      } else {
-        if ( fprintf( fp, "\n" ) < 0 ) error++;
-      }
+      if ( fprintf( fp, "\n" ) < 0 ) error++;
     }
     if ( error != 0 ) {
       worker_fclose( fp );
@@ -140,7 +135,7 @@ void ExeClass::addCommand( const char *format, ... )
 }
 
 /* THREADSAFE if worker == NULL or worker THREADSAFE
-              and if wconfig THREADSAFE or type !=TERMINAL */
+              and if wconfig THREADSAFE */
 void ExeClass::execute()
 {
   std::string exestr;
@@ -150,22 +145,9 @@ void ExeClass::execute()
 
   if ( worker != NULL ) worker->setWaitCursor();
 
-  if ( ( type == EXECUTE_TERMINAL_WAIT ) ||
-       ( type == EXECUTE_TERMINAL ) ) {
-    if ( type == EXECUTE_TERMINAL_WAIT ) {
-      if ( fprintf( fp, "echo %s\n", catalog.getLocale( 201 ) ) < 0 ) error++;
-      if ( fprintf( fp, "read x\n" ) < 0 ) error++;
-    }
-    exestr = AGUIXUtils::formatStringToString( wconfig->getTerminalStr(),
-                                               tmpfile );
-  } else {
-      exestr = "/bin/sh ";
-      exestr += tmpfile;
-  }
-  if ( type == EXECUTE_SHOW_OUTPUT ) {
-    if ( fprintf( fp, OUTPUT_BIN, tmpoutput ) < 0 ) error++;
-    if ( fprintf( fp, "\n" ) < 0 ) error++;
-  }
+  exestr = "/bin/sh ";
+  exestr += tmpfile;
+
   if ( worker_fclose( fp ) != 0 ) error++;
   fp = NULL;
 
@@ -216,8 +198,6 @@ int ExeClass::getOutputAndRV( char **return_output, int *return_value, int *retu
   char *erg = NULL;
   int rerg = -1;
   
-  /* only when type is normal because we want no user interaction */
-  if ( type != EXECUTE_NORMAL ) return 1;
   if ( fp == NULL ) return 1;
   
   if ( worker != NULL ) worker->setWaitCursor();
