@@ -1,6 +1,6 @@
 /* execlass.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2017 Ralf Hoffmann.
+ * Copyright (C) 2002-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,11 +28,7 @@
 class ExeClass
 {
 public:
-  typedef enum { EXECUTE_NORMAL = 0,
-                 EXECUTE_TERMINAL,
-                 EXECUTE_TERMINAL_WAIT,
-                 EXECUTE_SHOW_OUTPUT } execlass_execute_t;
-  ExeClass( execlass_execute_t exetype, class Worker *w = NULL );
+  ExeClass( class Worker *w = NULL );
   ~ExeClass();
   ExeClass( const ExeClass &other );
   ExeClass &operator=( const ExeClass &other );
@@ -52,7 +48,6 @@ public:
 protected:
   char *tmpfile, *tmpoutput, *tmperror;
   FILE *fp;
-  execlass_execute_t type;
   int lasterror;
   class Worker *worker;
 };
