@@ -1,6 +1,6 @@
 /* exprfilter_evalatoms.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2014-2016 Ralf Hoffmann.
+ * Copyright (C) 2014-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -91,7 +91,14 @@ void ExprAtomTypeCmp::eval( const NWCEntrySelectionState &element, ExprFilterEva
             // are not tested
             vm.pushValue( true );
         } else {
-            vm.pushValue( match( ft->getName() ) );
+            if ( ft->nameContainsFlags() ) {
+                NWCFlagProducer fpr( &element, NULL );
+                FlagReplacer rpl( fpr );
+
+                vm.pushValue( match( rpl.replaceFlags( ft->getName(), false ) ) );
+            } else {
+                vm.pushValue( match( ft->getName() ) );
+            }
         }
     } else {
         vm.pushValue( false );
