@@ -1,6 +1,6 @@
 /* fileentry.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2010-2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -666,6 +666,9 @@ FileEntry::FileEntry( const FileEntry &other )
   } else {
       m_bookmark_info = NULL;
   }
+
+  m_filetype_file_output = other.m_filetype_file_output;
+  m_mime_type = other.m_mime_type;
 }
 
 FileEntry::FileEntry( const NWC::FSEntry &other )
@@ -833,3 +836,23 @@ void FileEntry::setBookmarkMatch( bookmark_match_t m )
         m_bookmark_info->m_bookmark_match = m;
     }
 }
+
+void FileEntry::setFiletypeFileOutput( const std::string &output )
+{
+    m_filetype_file_output = output;
+}
+
+std::string FileEntry::getFiletypeFileOutput() const
+{
+    return m_filetype_file_output;
+}
+
+void FileEntry::setMimeType( const std::string &mimetype )
+{
+    m_mime_type = mimetype;
+}
+
+std::string FileEntry::getMimeType() const
+{
+    return m_mime_type;
+}
