@@ -1,6 +1,6 @@
 /* filereq.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2011-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -73,14 +73,14 @@ int FileRequester::request( const char *title,
   const int cmin = AContainer::ACONT_MINH +
                    AContainer::ACONT_MINW;
 
-  AWindow *win = new AWindow( aguix, 10, 10, 300, 200, 0, title, AWindow::AWINDOW_DIALOG );
+  AWindow *win = new AWindow( aguix, 10, 10, 300, 200, title, AWindow::AWINDOW_DIALOG );
   win->create();
 
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, infotext, 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, infotext ), 0, 0, cincwnr );
 
   AContainer *ac1_1 = ac1->add( new AContainer( win, 1, 2 ), 0, 1 );
   ac1_1->setMinSpace( 0 );
@@ -101,15 +101,11 @@ int FileRequester::request( const char *title,
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cnb = (Button*)ac1_2->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
   win->setDoTabCycling( true );
   win->contMaximize( true );
@@ -321,7 +317,7 @@ FileEntry *FileRequester::getNextFE()
   } else { \
     trow2 = lv->getActiveRow(); \
     if ( lv->isValidRow( trow2 ) == true ) { \
-      if ( lv->getData( trow2 ) == 0 ) { \
+      if ( lv->getData( trow2, 0 ) == 0 ) {           \
         if ( lv->getText( trow2, 0 ).length() > 0 ) { \
           endmode = 1; \
           okay = true; \
@@ -390,14 +386,14 @@ int FileRequester::request_entry( const char *title,
     }
   } else use_dir = dupstring( actdir );
 
-  win = new AWindow( aguix, 10, 10, 300, 200, 0, title, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 300, 200, title, AWindow::AWINDOW_DIALOG );
   win->create();
 
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, infotext, 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, infotext ), 0, 0, cincwnr );
   
   AContainer *ac1_1 = ac1->add( new AContainer( win, 1, 3 ), 0, 1 );
   ac1_1->setMinSpace( 0 );
@@ -426,15 +422,11 @@ int FileRequester::request_entry( const char *title,
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cb = (Button*)ac1_2->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
 
   okb->takeFocus();
@@ -516,7 +508,7 @@ int FileRequester::request_entry( const char *title,
               lasttime = msg->fieldlv.time;
             }
             if ( lv->isValidRow( lastrow ) == true ) {
-              if ( lv->getData( lastrow ) == 0 ) {
+              if ( lv->getData( lastrow, 0 ) == 0 ) {
                 // change sg2-text only for selected files
                 if ( sg2 != NULL ) sg2->setText( lv->getText( lastrow, 0 ).c_str() );
               }
@@ -530,7 +522,7 @@ int FileRequester::request_entry( const char *title,
             
             trow = lv->getActiveRow();
             if ( lv->isValidRow( trow ) == true ) {
-              if ( lv->getData( trow ) == 0 ) {
+              if ( lv->getData( trow, 0 ) == 0 ) {
                 // change sg2-text only for selected files
                 if ( sg2 != NULL ) sg2->setText( lv->getText( trow, 0 ).c_str() );
               }
@@ -571,7 +563,7 @@ int FileRequester::request_entry( const char *title,
       trow = lv->getActiveRow();
       if ( lv->isValidRow( trow ) == true ) {
         if ( lv->getText( trow, 0 ).length() > 0 ) {
-          if ( lv->getData( trow ) == 0 ) {
+          if ( lv->getData( trow, 0 ) == 0 ) {
             last_entry_str += lv->getText( trow, 0 );
           } else last_entry_str = "";
         } else last_entry_str = "";
