@@ -60,7 +60,7 @@ struct FTLsort1 : public std::binary_function<int, int, bool>
     FTLsort1( const std::vector<FlatTypeList::flattypelist_t> &list ) : m_list( list ) {}
     bool operator() ( int e1, int e2 )
     {
-        if ( m_list[e1].filetype->getNameString() < m_list[e2].filetype->getNameString() ) return true;
+        if ( m_list[e1].filetype->getName() < m_list[e2].filetype->getName() ) return true;
         return false;
     }
 
