@@ -82,7 +82,7 @@ static const struct request_fonts_def {
 			      "-*-helvetica-medium-o-*-*-%d-*-*-*-*-*-*-*", 0},
 			    { "helvetica bold italic", FontRequester::request_fonts::SCALABLE,
 			      "-*-helvetica-bold-o-*-*-%d-*-*-*-*-*-*-*", 0},
-			    { "any font famliy", FontRequester::request_fonts::SCALABLE,
+			    { "any font family", FontRequester::request_fonts::SCALABLE,
 			      "-*-*-medium-r-*-*-%d-*-*-*-*-*-*-*", 0},
 			    { "generic", FontRequester::request_fonts::SCALABLE,
 			      "-*-*-*-*-*-*-%d-*-*-*-*-*-*-*", 0}
