@@ -1,6 +1,6 @@
 /* functionproto.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -112,6 +112,9 @@ public:
   virtual command_categories_t getCategory() const;
 
     virtual std::string getStringRepresentation();
+
+    virtual bool isInteractiveRun() const;
+    virtual void setInteractiveRun();
 protected:
   static const char *name;
   bool hasConfigure;
