@@ -82,26 +82,33 @@ void WConfig::setDefaultConfig()
   addListCol( 1, WorkerTypes::LISTCOL_SIZE );
   addListCol( 1, WorkerTypes::LISTCOL_NAME );
   addListCol( 1, WorkerTypes::LISTCOL_TYPE );
-  setStatusbar(0,2);
-  setStatusbar(1,3);
-  setSelLVB(0,2);
-  setSelLVB(1,4);
-  setUnselLVB(0,1);
-  setUnselLVB(1,0);
-  setSelDir(0,2);
-  setSelDir(1,3);
-  setUnselDir(0,3);
-  setUnselDir(1,0);
-  setSelFile(0,2);
-  setSelFile(1,1);
-  setUnselFile(0,1);
-  setUnselFile(1,0);
-  setClockbar(0,2);
-  setClockbar(1,6);
-  setRequest(0,1);
-  setRequest(1,0);
-  setLVHeader( 0, 1 );
-  setLVHeader( 1, 0 );
+
+  FaceDB faces;
+
+  faces.setColor( "statusbar-fg", 2 );
+  faces.setColor( "statusbar-bg", 3 );
+
+  faces.setColor( "lvb-active-fg", 2 );
+  faces.setColor( "lvb-active-bg", 4 );
+  faces.setColor( "lvb-inactive-fg", 1 );
+  faces.setColor( "lvb-inactive-bg", 0 );
+  faces.setColor( "dirview-dir-select-fg", 2 );
+  faces.setColor( "dirview-dir-select-bg", 3 );
+  faces.setColor( "dirview-dir-normal-fg", 3 );
+  faces.setColor( "dirview-dir-normal-bg", 0 );
+  faces.setColor( "dirview-file-select-fg", 2 );
+  faces.setColor( "dirview-file-select-bg", 1 );
+  faces.setColor( "dirview-file-normal-fg", 1 );
+  faces.setColor( "dirview-file-normal-bg", 0 );
+  faces.setColor( "clockbar-fg", 2 );
+  faces.setColor( "clockbar-bg", 6 );
+  faces.setColor( "request-fg", 1 );
+  faces.setColor( "request-bg", 0 );
+  faces.setColor( "dirview-header-fg", 1 );
+  faces.setColor( "dirview-header-bg", 0 );
+
+  setFaceDB( faces );
+
   setStartDir(0,"");
   setStartDir(1,"");
 #ifdef HAVE_XFT
