@@ -1,6 +1,6 @@
 /* informationmode.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2009,2012-2013,2016 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -35,6 +35,7 @@
 #include <aguix/util.h>
 #include "datei.h"
 #include "nwc_path.hh"
+#include "nwcentryselectionstate.hh"
 
 const char *InformationMode::type="InformationMode";
 
@@ -232,6 +233,7 @@ void InformationMode::showinfos()
   struct tm *timeptr;
   time_t tvar;
   char *istr;
+  std::string tstr2;
   
   showno=true;
   fe=lastactivefe;
@@ -275,10 +277,26 @@ void InformationMode::showinfos()
     _freesafe(tstr);
     
     if(fe->filetype!=NULL) {
-      tstr=(char*)_allocsafe(strlen("%s: %s")+
-                             strlen(catalog.getLocale(178))+
-                             strlen(fe->filetype->getName().c_str())+1);
-      sprintf(tstr,"%s: %s",catalog.getLocale(178),fe->filetype->getName().c_str());
+        NWCFlagProducer fpr( NULL, fe );
+        FlagReplacer rpl( fpr );
+        std::string filetype_str;
+
+        if ( fe->filetype->nameContainsFlags() ) {
+            filetype_str = rpl.replaceFlags( fe->filetype->getName(), false );
+        } else {
+            filetype_str = fe->filetype->getName();
+        }
+
+        tstr2 = AGUIXUtils::formatStringToString( "%s: %s",
+                                                  catalog.getLocale( 178 ),
+                                                  filetype_str.c_str() );
+
+        if ( ! fe->getFiletypeFileOutput().empty() ) {
+            tstr2 += " / ";
+            tstr2 += fe->getFiletypeFileOutput();
+        }
+
+        lv->setText( 3, 0, tstr2 );
     } else {
       if(fe->isDir()==true) {
 //        tstr=(char*)_allocsafe(strlen("%s: %s")+
@@ -295,9 +313,9 @@ void InformationMode::showinfos()
                                strlen(wconfig->getnotyettype()->getName().c_str())+1);
         sprintf(tstr,"%s: %s",catalog.getLocale(178),wconfig->getnotyettype()->getName().c_str());
       }
+      lv->setText( 3, 0, tstr);
+      _freesafe(tstr);
     }
-    lv->setText( 3, 0, tstr);
-    _freesafe(tstr);
 
     lv->setText( 4, 0, "" );
     if ( fe->isCorrupt == false ) {
