@@ -189,12 +189,12 @@ void Lister::setFocus(bool state)
   int fg,bg;
   hasFocus=state;
   if(state==true) {
-    fg=wconfig->getSelLVB(0);
-    bg=wconfig->getSelLVB(1);
+      fg = aguix->getFaces().getColor( "lvb-active-fg" );
+      bg = aguix->getFaces().getColor( "lvb-active-bg" );
     if(activemode!=NULL) activemode->activate();
   } else {
-    fg=wconfig->getUnselLVB(0);
-    bg=wconfig->getUnselLVB(1);
+      fg = aguix->getFaces().getColor( "lvb-inactive-fg" );
+      bg = aguix->getFaces().getColor( "lvb-inactive-bg" );
     if(activemode!=NULL) activemode->deactivate();
   }
   lvb->setFG(0,fg);
@@ -584,11 +584,11 @@ void  Lister::relayout()
 {
   int fg,bg;
   if(hasFocus==true) {
-    fg=wconfig->getSelLVB(0);
-    bg=wconfig->getSelLVB(1);
+      fg = aguix->getFaces().getColor( "lvb-active-fg" );
+      bg = aguix->getFaces().getColor( "lvb-active-bg" );
   } else {
-    fg=wconfig->getUnselLVB(0);
-    bg=wconfig->getUnselLVB(1);
+      fg = aguix->getFaces().getColor( "lvb-inactive-fg" );
+      bg = aguix->getFaces().getColor( "lvb-inactive-bg" );
   }
   lvb->setFG(0,fg);
   lvb->setBG(0,bg);
