@@ -1,6 +1,6 @@
 /* lister.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -44,7 +44,7 @@ typedef enum {
 class Lister
 {
 public:
-  Lister(Worker*);
+  Lister( Worker*, int side );
   ~Lister();
   Lister( const Lister &other );
   Lister &operator=( const Lister &other );
@@ -86,6 +86,7 @@ private:
   AGUIX *aguix;
   AWindow *win;
   Button *lvb;
+  Button *m_configure_b;
   ListerMode *activemode;
   int activemodeid;
   ListerMode **modes;
@@ -95,6 +96,7 @@ private:
 
   AContainer *m_cont;
   AContainer *m_mode_cont;
+  AContainer *m_button_cont;
 
     std::string m_last_path;
 };
