@@ -141,9 +141,16 @@ void ListerMode::runCommand( const std::string &command )
 }
 
 void ListerMode::registerCommand( const std::string &command,
-                                  std::function< void (void) > callback )
+                                  std::function< void (void) > callback,
+                                  const std::string &description,
+                                  FunctionProto::command_categories_t category )
 {
     m_commands[ command ] = callback;
+
+    if ( ! description.empty() &&
+         m_command_info.count( command ) == 0 ) {
+        m_command_info[ command ] = std::make_tuple( description, category );
+    }
 }
 
 void ListerMode::runCommand( const std::string &command, const std::list< RefCount< ArgClass > > &args )
@@ -162,9 +169,16 @@ void ListerMode::runCommand( const std::string &command, const std::list< RefCou
 }
 
 void ListerMode::registerCommand( const std::string &command,
-                                  const std::function< void ( const std::list< RefCount< ArgClass > > ) > callback )
+                                  const std::function< void ( const std::list< RefCount< ArgClass > > ) > callback,
+                                  const std::string &description,
+                                  FunctionProto::command_categories_t category )
 {
     m_commands_with_args[command] = callback;
+
+    if ( ! description.empty() &&
+         m_command_info.count( command ) == 0 ) {
+        m_command_info[ command ] = std::make_tuple( description, category );
+    }
 }
 
 void ListerMode::runCommandWithStrArgs( const std::string &command_str )
@@ -192,7 +206,7 @@ void ListerMode::runCommandWithStrArgs( const std::string &command_str )
         }
 
         if ( ! command.empty() ) {
-            if ( string_args.size() > 0 ||
+            if ( string_args.size() > 0 &&
                  m_commands_with_args.count( command ) > 0 ) {
                 runCommand( command, string_args );
             } else {
@@ -237,17 +251,38 @@ void ListerMode::not_supported()
                                                         catalog.getLocale( 11 ) );
 }
 
-std::list< std::string > ListerMode::getListOfCommandsWithoutArgs()
+std::list< WorkerTypes::reg_command_info_t > ListerMode::getListOfCommandsWithoutArgs() const
 {
-    std::list< std::string > res;
+    std::list< WorkerTypes::reg_command_info_t > res;
 
     for ( auto &e : m_commands ) {
-        res.push_back( e.first );
+        WorkerTypes::reg_command_info_t t = { .name = e.first,
+                                              .description = "",
+                                              .category = FunctionProto::CAT_OTHER };
+        if ( m_command_info.count( e.first ) > 0 ) {
+            t.description = std::get<0>( m_command_info.at( e.first ) );
+            t.category = std::get<1>( m_command_info.at( e.first ) );
+        }
+
+        res.push_back( t );
     }
 
     return res;
 }
 
+WorkerTypes::reg_command_info_t ListerMode::getCommandInfo( const std::string &command ) const
+{
+    if ( m_command_info.count( command ) == 0 ) return {};
+
+    WorkerTypes::reg_command_info_t res;
+
+    res.name = command;
+    res.description = std::get<0>( m_command_info.at( command ) );
+    res.category = std::get<1>( m_command_info.at( command ) );
+
+    return res;
+}
+
 void ListerMode::finalizeBGOps()
 {
 }
