@@ -79,5 +79,5 @@ MakeDirOp::run( WPUContext *wpu, ActionMessage *msg )
 const char *
 MakeDirOp::getDescription()
 {
-  return catalog.getLocaleCom(27);
+  return catalog.getLocale(1268);
 }
