@@ -77,7 +77,7 @@ void MenuTreeUI::show( bool show_recently_used )
         twin = m_aguix->getTransientWindow();
     }
 
-    AWindow *mainwin = new AWindow( m_aguix, 10, 10, 50, 10, catalog.getLocaleCom( 62 ) );
+    AWindow *mainwin = new AWindow( m_aguix, 10, 10, 50, 10, catalog.getLocale( 1303 ) );
     mainwin->create();
 
     if ( twin != NULL ) {
@@ -422,8 +422,9 @@ void MenuTreeUI::show( bool show_recently_used )
                                     filter += "/";
                                 }
                                 filter += current_filter;
-    
-                                std::string best_hit = m_pdb->getBestHit( filter );
+
+                                time_t t1;
+                                std::string best_hit = m_pdb->getBestHit( filter, t1 );
 
                                 for ( int row = 0; row < m_lv->getElements(); row++ ) {
                                     std::string fullname = prefix;
@@ -515,7 +516,8 @@ void MenuTreeUI::show( bool show_recently_used )
                 }
                 filter += current_filter;
                 m_pdb->pushAccess( filter,
-                                   fullname );
+                                   fullname,
+                                   0 );
             }
 
             int pos = 0;
