@@ -94,6 +94,12 @@ int NM_Filetype_Thread::slave_checkFiletype( const check_entry_t &entry,
     if ( fe1->getCustomColorSet() != 0 ) {
         res.custom_color = fe1->getCustomColor();
     }
+
+    if ( ! fe1->getFiletypeFileOutput().empty() ) {
+        res.filetype_file_output = fe1->getFiletypeFileOutput();
+        res.mime_type = fe1->getMimeType();
+    }
+    
     delete fe1;
 
     res_return = res;
