@@ -93,7 +93,7 @@ int ChangeListerSetOp::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *ChangeListerSetOp::getDescription()
 {
-  return catalog.getLocaleCom(19);
+  return catalog.getLocale(1260);
 }
 
 int ChangeListerSetOp::configure()
@@ -112,8 +112,8 @@ int ChangeListerSetOp::configure()
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
   
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(19))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(19));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
@@ -290,7 +290,7 @@ int SwitchListerOp::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *SwitchListerOp::getDescription()
 {
-  return catalog.getLocaleCom(20);
+  return catalog.getLocale(1261);
 }
 
 /*************
@@ -382,7 +382,7 @@ int FilterSelectOp::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *FilterSelectOp::getDescription()
 {
-  return catalog.getLocaleCom(21);
+  return catalog.getLocale(1262);
 }
 
 int FilterSelectOp::configure()
@@ -399,8 +399,8 @@ int FilterSelectOp::configure()
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
 
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(21))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(21));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
@@ -792,7 +792,7 @@ int FilterUnSelectOp::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *FilterUnSelectOp::getDescription()
 {
-  return catalog.getLocaleCom(22);
+  return catalog.getLocale(1263);
 }
 
 int FilterUnSelectOp::configure()
@@ -809,8 +809,8 @@ int FilterUnSelectOp::configure()
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
 
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(22))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(22));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
@@ -941,7 +941,7 @@ int Path2OSideOp::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *Path2OSideOp::getDescription()
 {
-  return catalog.getLocaleCom(23);
+  return catalog.getLocale(1264);
 }
 
 /*************
@@ -989,7 +989,7 @@ int QuitOp::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *QuitOp::getDescription()
 {
-  return catalog.getLocaleCom(24);
+  return catalog.getLocale(1265);
 }
 
 int QuitOp::configure()
@@ -1008,8 +1008,8 @@ int QuitOp::configure()
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
   
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(24))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(24));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
