@@ -1,6 +1,6 @@
 /* nwcentryselectionstate.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013-2019 Ralf Hoffmann.
+ * Copyright (C) 2013-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,7 @@
 #include "grouphash.h"
 #include "wcfiletype.hh"
 #include "wconfig.h"
+#include "flagreplacer.hh"
 
 NWCEntrySelectionState::NWCEntrySelectionState( int entry_id )
     : m_entry_id( entry_id ),
@@ -41,7 +42,9 @@ NWCEntrySelectionState::NWCEntrySelectionState( const NWCEntrySelectionState &ot
       m_use( other.m_use ),
       m_filetype( other.m_filetype ),
       m_colors( other.m_colors ),
-      m_selected( other.m_selected )
+      m_selected( other.m_selected ),
+      m_filetype_file_output( other.m_filetype_file_output ),
+      m_mime_type( other.m_mime_type )
 {
     if ( other.m_bookmark_info.get() != NULL ) {
         m_bookmark_info = new NWCBookmarkInfo( *other.m_bookmark_info );
@@ -53,7 +56,9 @@ NWCEntrySelectionState::NWCEntrySelectionState( const NWCEntrySelectionState &ot
       m_use( other.m_use ),
       m_filetype( other.m_filetype ),
       m_colors( other.m_colors ),
-      m_selected( other.m_selected )
+      m_selected( other.m_selected ),
+      m_filetype_file_output( other.m_filetype_file_output ),
+      m_mime_type( other.m_mime_type )
 {
     if ( decoupleDir ) {
         const NWC::FSEntry *fse = other.getNWCEntry();
@@ -81,6 +86,8 @@ NWCEntrySelectionState &NWCEntrySelectionState::operator=( const NWCEntrySelecti
         m_filetype = rhs.m_filetype;
         m_colors = rhs.m_colors;
         m_selected = rhs.m_selected;
+        m_filetype_file_output = rhs.m_filetype_file_output;
+        m_mime_type = rhs.m_mime_type;
 
         if ( rhs.m_bookmark_info.get() != NULL ) {
             m_bookmark_info = new NWCBookmarkInfo( *rhs.m_bookmark_info );
@@ -242,7 +249,7 @@ int NWCEntrySelectionState::sortfunction( const NWCEntrySelectionState &e1,
           else if ( fse1->stat_lastchange() > fse2->stat_lastchange() ) comp = 1;
           else comp = fse1->getFullname().compare( fse2->getFullname() );
           break;
-      case SORT_TYPE:
+      case SORT_TYPE: {
           if ( e1.getFiletype() != NULL ) {
               ft1 = e1.getFiletype();
           } else {
@@ -261,10 +268,28 @@ int NWCEntrySelectionState::sortfunction( const NWCEntrySelectionState &e1,
                   ft2 = wconfig->getnotyettype();
               }
           }
-          comp = ft1->getName().compare( ft2->getName() );
+
+          NWCFlagProducer fpr1( &e1, NULL );
+          NWCFlagProducer fpr2( &e2, NULL );
+          FlagReplacer rpl1( fpr1 );
+          FlagReplacer rpl2( fpr2 );
+
+          std::string s1 = getStringRepresentation( WorkerTypes::LISTCOL_TYPE,
+                                                    0,
+                                                    fse1,
+                                                    ft1,
+                                                    &rpl1 );
+          std::string s2 = getStringRepresentation( WorkerTypes::LISTCOL_TYPE,
+                                                    0,
+                                                    fse2,
+                                                    ft2,
+                                                    &rpl2 );
+
+          comp = s1.compare( s2 );
           if ( comp == 0 )
               comp = fse1->getFullname().compare( fse2->getFullname() );
           break;
+      }
       case SORT_OWNER:
           // first cmp usernames
           // if equal cmp groupnames
@@ -438,7 +463,8 @@ bool NWCEntrySelectionState::getSelected() const
 }
 
 std::string NWCEntrySelectionState::getStringRepresentation( WorkerTypes::listcol_t type,
-                                                             int file_name_skip ) const
+                                                             int file_name_skip,
+                                                             FlagReplacer *rpl ) const
 {
     std::string res;
 
@@ -446,13 +472,14 @@ std::string NWCEntrySelectionState::getStringRepresentation( WorkerTypes::listco
 
     if ( ! fse ) return res;
 
-    return getStringRepresentation( type, file_name_skip, fse, m_filetype );
+    return getStringRepresentation( type, file_name_skip, fse, m_filetype, rpl );
 }
 
 std::string NWCEntrySelectionState::getStringRepresentation( WorkerTypes::listcol_t type,
                                                              int file_name_skip,
                                                              const NWC::FSEntry *fse,
-                                                             const WCFiletype *filetype )
+                                                             const WCFiletype *filetype,
+                                                             FlagReplacer *rpl )
 {
     std::string res;
     struct tm *timeptr;
@@ -531,7 +558,11 @@ std::string NWCEntrySelectionState::getStringRepresentation( WorkerTypes::listco
             break;
         case WorkerTypes::LISTCOL_TYPE:
             if ( filetype != NULL ) {
-                res = filetype->getName();
+                if ( rpl && filetype->nameContainsFlags() ) {
+                    res = rpl->replaceFlags( filetype->getName(), false );
+                } else {
+                    res = filetype->getName();
+                }
             } else {
                 if ( fse->isDir( true ) == true ) {
                     // Dir
@@ -602,3 +633,41 @@ void NWCEntrySelectionState::setBookmarkInfo( RefCount< NWCBookmarkInfo >  bookm
 {
     m_bookmark_info = bookmark_info;
 }
+
+void NWCEntrySelectionState::setFiletypeFileOutput( const std::string &output )
+{
+    m_filetype_file_output = output;
+}
+
+std::string NWCEntrySelectionState::getFiletypeFileOutput() const
+{
+    return m_filetype_file_output;
+}
+
+void NWCEntrySelectionState::setMimeType( const std::string &mimetype )
+{
+    m_mime_type = mimetype;
+}
+
+std::string NWCEntrySelectionState::getMimeType() const
+{
+    return m_mime_type;
+}
+
+std::string NWCFlagProducer::getFlagReplacement( const std::string &flag )
+{
+    if ( flag == "mimetype" ) {
+        if ( m_es ) {
+            return m_es->getMimeType();
+        } else if ( m_fe ) {
+            return m_fe->getMimeType();
+        }
+    }
+
+    return "";
+}
+
+bool NWCFlagProducer::hasFlag( const std::string &str )
+{
+    return str == "mimetype";
+}
