@@ -84,7 +84,7 @@ int OpenContextMenuOp::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *OpenContextMenuOp::getDescription()
 {
-    return catalog.getLocaleCom( 52 );
+    return catalog.getLocale( 1293);
 }
 
 bool
