@@ -61,5 +61,5 @@ int OpenWorkerMenuOp::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *OpenWorkerMenuOp::getDescription()
 {
-    return catalog.getLocaleCom( 54 );
+    return catalog.getLocale( 1295 );
 }
