@@ -731,6 +731,7 @@ void OwnOp::externprog( WPUContext *wpu, ActionMessage *msg )
             }
             if(  cancel == false ) {
                 std::string exestr;
+                bool remove_after_exec = true;
 
                 if ( ( ownstart == OWNOP_START_IN_TERMINAL_AND_WAIT4KEY ) ||
                      ( ownstart == OWNOP_START_IN_TERMINAL ) ) {
@@ -739,8 +740,7 @@ void OwnOp::externprog( WPUContext *wpu, ActionMessage *msg )
                         fp->putStringExt( "echo %s\n", catalog.getLocale( 201 ) );
                         fp->putString( "read x\n" );
                     }
-                    exestr = AGUIXUtils::formatStringToString( wconfig->getTerminalStr(),
-                                                               tmpname );
+                    exestr = Worker::getTerminalCommand( tmpname, tmpoutput, remove_after_exec );
                 } else {
                     exestr = "/bin/sh ";
                     exestr += tmpname;
@@ -761,7 +761,10 @@ void OwnOp::externprog( WPUContext *wpu, ActionMessage *msg )
                 if ( fp->errors() == 0 ) {
                     worker_chmod( tmpname, 0700 );
                     removeTMPFiles = false;
-                    msg->getWorker()->runCommand( exestr.c_str(), tmpname, tmpoutput, inbackground, pea );
+                    msg->getWorker()->runCommand( exestr.c_str(),
+                                                  remove_after_exec ? tmpname : NULL,
+                                                  remove_after_exec ? tmpoutput : NULL,
+                                                  inbackground, pea );
                 } else {
                     std::string text = AGUIXUtils::formatStringToString( catalog.getLocale( 647 ), tmpname );
                     std::string button = catalog.getLocale( 11 );
