@@ -102,15 +102,25 @@ int PathJumpOp::run( WPUContext *wpu, ActionMessage *msg )
         ui.setCurrentBasename( basename );
     }
 
-    int res = ui.mainLoop( m_initial_tab == SHOW_BY_FILTER ? true : false );
+    PathJumpUI::initial_tab_t show_tab = PathJumpUI::SHOW_BY_TIME;
+    if ( m_initial_tab == SHOW_BY_FILTER ) {
+        show_tab = PathJumpUI::SHOW_BY_FILTER;
+    } else if ( m_initial_tab == SHOW_BY_PROGRAM ) {
+        show_tab = PathJumpUI::SHOW_BY_PROGRAM;
+    }
+
+    int res = ui.mainLoop( show_tab );
 
     if ( res == 1 ) {
-        std::string sel_path = ui.getSelectedPath();
+        bool stored = false;
+        std::string sel_path = ui.getSelectedPath( stored );
 
         std::list< RefCount< ArgClass > > args;
 
         if ( lm1 ) {
             args.push_back( new StringArg( sel_path ) );
+            args.push_back( new KeyValueArg( "pathDBStored",
+                                             std::make_shared< BoolArg >( stored ) ) );
             lm1->runCommand( "enter_dir", args );
 
             // if ( highlight_entry.empty() == false ) {
@@ -152,6 +162,9 @@ PathJumpOp::save( Datei *fh )
         case SHOW_BY_FILTER:
             fh->configPutPair( "initialtab", "showbyfilter" );
             break;
+        case SHOW_BY_PROGRAM:
+            fh->configPutPair( "initialtab", "showbyprogram" );
+            break;
         default:
             // don't save default value to be backward compatible
             break;
@@ -186,12 +199,16 @@ PathJumpOp::configure()
     rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, AContainer::CO_INCWNR );
     rcyb->addOption( catalog.getLocale( 1225 ) );
     rcyb->addOption( catalog.getLocale( 1226 ) );
+    rcyb->addOption( catalog.getLocale( 1327 ) );
     rcyb->resize( rcyb->getMaxSize(), rcyb->getHeight() );
     ac1_1->readLimits();
     switch ( m_initial_tab ) {
         case SHOW_BY_FILTER:
             rcyb->setOption( 1 );
             break;
+        case SHOW_BY_PROGRAM:
+            rcyb->setOption( 2 );
+            break;
         default:
             rcyb->setOption( 0 );
             break;
@@ -238,6 +255,9 @@ PathJumpOp::configure()
             case 1:
                 m_initial_tab = SHOW_BY_FILTER;
                 break;
+            case 2:
+                m_initial_tab = SHOW_BY_PROGRAM;
+                break;
             default:
                 m_initial_tab = SHOW_BY_TIME;
                 break;
