@@ -1,6 +1,6 @@
 /* prefixdbentry.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2010 Ralf Hoffmann.
+ * Copyright (C) 2010-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -43,20 +43,21 @@ bool PrefixDBEntry::operator<( const PrefixDBEntry &rhs ) const
     return m_prefix < rhs.m_prefix;
 }
 
-void PrefixDBEntry::storeAccess( const std::string &value )
+void PrefixDBEntry::storeAccess( const std::string &value, time_t last_use )
 {
-    std::list< std::pair< std::string, float > >::iterator it1;
+    std::list< std::tuple< std::string, float, time_t > >::iterator it1;
 
     for ( it1 = m_strings.begin();
-	  it1 != m_strings.end();
-	  it1++ ) {
-	if ( it1->first == value ) break;
+          it1 != m_strings.end();
+          it1++ ) {
+        if ( std::get<0>( *it1 ) == value ) break;
     }
     
     if ( it1 != m_strings.end() ) {
-	it1->second++;
+        std::get<1>( *it1 )++;
+        std::get<2>( *it1 ) = last_use;
     } else {
-	m_strings.push_back( std::make_pair( value, 1.0 ) );
+        m_strings.push_back( std::make_tuple( value, 1.0, last_use ) );
     }
 }
 
@@ -68,22 +69,29 @@ std::string PrefixDBEntry::getBestHit() const
 
 std::string PrefixDBEntry::getBestHit( float &count ) const
 {
-    std::list< std::pair< std::string, float > >::const_iterator it1, best_hit;
+    time_t t1;
+    return getBestHit( count, t1 );
+}
+
+std::string PrefixDBEntry::getBestHit( float &count, time_t &last_use ) const
+{
+    std::list< std::tuple< std::string, float, time_t > >::const_iterator it1, best_hit;
 
     if ( m_strings.empty() ) return "";
 
     best_hit = m_strings.begin();
 
     for ( it1 = m_strings.begin();
-	  it1 != m_strings.end();
-	  it1++ ) {
-	if ( it1->second > best_hit->second ) {
-	    best_hit = it1;
-	}
+          it1 != m_strings.end();
+          it1++ ) {
+        if ( std::get<1>( *it1 ) > std::get<1>( *best_hit ) ) {
+            best_hit = it1;
+        }
     }
 
-    count = best_hit->second;
-    return best_hit->first;;
+    count = std::get<1>( *best_hit );
+    last_use = std::get<2>( *best_hit );
+    return std::get<0>( *best_hit );
 }
 
 const std::string &PrefixDBEntry::getPrefix() const
@@ -91,32 +99,17 @@ const std::string &PrefixDBEntry::getPrefix() const
     return m_prefix;
 }
 
-const std::list< std::pair< std::string, float > > &PrefixDBEntry::getStrings() const
+const std::list< std::tuple< std::string, float, time_t > > &PrefixDBEntry::getStrings() const
 {
     return m_strings;
 }
 
 void PrefixDBEntry::age( float factor )
 {
-    std::list< std::pair< std::string, float > >::iterator it1;
-
-    for ( it1 = m_strings.begin();
-	  it1 != m_strings.end();
-	  it1++ ) {
-	it1->second *= factor;
-    }
-}
-
-void PrefixDBEntry::write( std::ofstream &ofile ) const
-{
-    ofile << "prefix=" << m_prefix << std::endl;
-
-    std::list< std::pair< std::string, float > >::const_iterator it1;
-
-    for ( it1 = m_strings.begin();
-	  it1 != m_strings.end();
-	  it1++ ) {
-	ofile << "value=" << it1->second << ":" << it1->first << std::endl;
+    for ( auto it1 = m_strings.begin();
+          it1 != m_strings.end();
+          it1++ ) {
+        std::get<1>( *it1 ) *= factor;
     }
 }
 
@@ -124,56 +117,21 @@ void PrefixDBEntry::write( Datei &fh ) const
 {
     fh.configPutPairString( "prefix", m_prefix.c_str() );
 
-    std::list< std::pair< std::string, float > >::const_iterator it1;
+    std::list< std::tuple< std::string, float, time_t > >::const_iterator it1;
 
     for ( it1 = m_strings.begin();
           it1 != m_strings.end();
           it1++ ) {
-        std::string f1 = AGUIXUtils::formatStringToString( "%f", it1->second );
+        std::string f1 = AGUIXUtils::formatStringToString( "%f", std::get<1>( *it1 ) );
+        if ( std::get<2>( *it1 ) != 0 ) {
+            fh.configPutPairString( "value",
+                                    AGUIXUtils::formatStringToString( "lastuse:%lu", std::get<2>( *it1 ) ).c_str() );
+        }
         fh.configPutPairString( "value", f1.c_str() );
-        fh.configPutPairString( "name", it1->first.c_str() );
+        fh.configPutPairString( "name", std::get<0>( *it1 ).c_str() );
     }
 }
 
-bool PrefixDBEntry::read( std::ifstream &ifile )
-{
-    bool failed = true;
-    std::string line;
-
-    m_strings.clear();
-    m_prefix = "";
-
-    if ( std::getline( ifile, line ) ) {
-	if ( line.compare( 0, std::string( "prefix=" ).length(), "prefix=" ) == 0 ) {
-	    m_prefix = std::string( line, std::string( "prefix=" ).length() );
-	    failed = false;
-	}
-    }
-
-    if ( ! failed ) {
-	while ( ! failed && std::getline( ifile, line ) ) {
-	    if ( line == "end_entry" ) break;
-
-	    if ( line.compare( 0, std::string( "value=" ).length(), "value=" ) == 0 ) {
-		std::string value( line, std::string( "value=" ).length() );
-		std::string::size_type pos = value.find( ':' );
-		if ( pos != std::string::npos ) {
-		    std::string count( value, 0, pos );
-		    std::string str1( value, pos + 1 );
-		    
-		    m_strings.push_back( std::make_pair( str1, atof( count.c_str() ) ) );
-		} else {
-		    failed = true;
-		}
-	    } else {
-		failed = true;
-	    }
-	}
-    }
-
-    return failed;
-}
-
 bool PrefixDBEntry::read( FILE *fp )
 {
     if ( fp == NULL ) return true;
@@ -185,6 +143,7 @@ bool PrefixDBEntry::read( FILE *fp )
     int found_error = 0;
     std::string str1;
     float value = -1.0;
+    time_t last_use = 0;
 
     for (;;) {
         if ( worker_token == PREFIX_WCP ) {
@@ -227,7 +186,16 @@ bool PrefixDBEntry::read( FILE *fp )
             str1 = yylval.strptr;
             if ( sscanf( yylval.strptr, "%f", &value ) == 1 ) {
             } else {
-                value = -1.0;
+                // this is an ugly workaround to stay compatible with
+                // older version
+                if ( AGUIXUtils::starts_with( str1, "lastuse:" ) ) {
+                    std::string str2( str1, strlen( "lastuse:" ) );
+                    if ( sscanf( str2.c_str(), "%lu", &last_use ) != 1 ) {
+                        last_use = 0;
+                    }
+                } else {
+                    value = -1.0;
+                }
             }
             readtoken();
 
@@ -260,7 +228,8 @@ bool PrefixDBEntry::read( FILE *fp )
             readtoken();
 
             if ( value > 0.0 ) {
-                m_strings.push_back( std::make_pair( str1, value ) );
+                m_strings.push_back( std::make_tuple( str1, value, last_use ) );
+                last_use = 0;
             }
         } else {
             break;
