@@ -1,6 +1,6 @@
 /* processhandler.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2010 Ralf Hoffmann.
+ * Copyright (C) 2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -33,8 +33,11 @@ void ProcessHandler::checkChildren( int pid )
     if ( pid == 0 ) return;
 
     for ( it1 = m_child_actions.begin();
-          it1 != m_child_actions.end();
-          it1++ ) {
+          it1 != m_child_actions.end(); ) {
+        std::list< list_entry_t >::iterator next_it = it1;
+
+        next_it++;
+
         if ( pid < 0 || it1->first == pid ) {
             int status = 0, ret;
 
@@ -49,17 +52,13 @@ void ProcessHandler::checkChildren( int pid )
                     it1->second->callback( WEXITSTATUS( status ) );
                 }
 
-                std::list< list_entry_t >::iterator it2;
-
-                it2 = it1;
-                it2++;
-
                 m_child_actions.erase( it1 );
-                it1 = it2;
     
                 if ( pid > 0 ) break;
             }
         }
+
+        it1 = next_it;
     }
 }
 
@@ -67,3 +66,8 @@ bool ProcessHandler::empty() const
 {
     return m_child_actions.empty();
 }
+
+void ProcessHandler::clearProcesses()
+{
+    m_child_actions.clear();
+}
