@@ -75,7 +75,7 @@ int RunCustomAction::run( WPUContext *wpu, ActionMessage *msg )
 
 const char *RunCustomAction::getDescription()
 {
-    return catalog.getLocaleCom( 53 );
+    return catalog.getLocale( 1294 );
 }
 
 void RunCustomAction::normalmoderuncustomaction( ActionMessage *am )
@@ -198,8 +198,8 @@ int RunCustomAction::configure()
     char *tstr;
   
     tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) +
-                              strlen( catalog.getLocaleCom( 4 ) ) + 1 );
-    sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 4 ) );
+                              strlen( catalog.getLocale( 1245 ) ) + 1 );
+    sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocale( 1245 ) );
     win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
     win->create();
     _freesafe( tstr );
