@@ -130,7 +130,7 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
                          ( ( push_useoutput == true ) ? true : false ),
                          WPUContext::PERSIST_ALL ) == WPUContext::PARSE_SUCCESS ) {
           if ( push_useoutput == true ) {
-            std::unique_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL, msg->getWorker() ) );
+            std::unique_ptr<ExeClass> ec( new ExeClass( msg->getWorker() ) );
             ec->cdDir( wpu->getBaseDir() );
             ec->addCommand( "%s", res_str.c_str() );
             tstr2 = ec->getOutput( &exeerror );
@@ -271,7 +271,7 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
                            ( ( progress_useoutput == true ) ? true : false ),
                            WPUContext::PERSIST_ALL ) == WPUContext::PARSE_SUCCESS ) {
             if ( progress_useoutput == true ) {
-              std::unique_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL ) );
+              std::unique_ptr<ExeClass> ec( new ExeClass() );
               ec->cdDir( wpu->getBaseDir() );
               ec->addCommand( "%s", res_str.c_str() );
               tstr2 = ec->getOutput( &exeerror );
@@ -322,7 +322,7 @@ ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
                            ( ( wintext_useoutput == true ) ? true : false ),
                            WPUContext::PERSIST_ALL ) == WPUContext::PARSE_SUCCESS ) {
             if ( wintext_useoutput == true ) {
-              std::unique_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL ) );
+              std::unique_ptr<ExeClass> ec( new ExeClass() );
               ec->cdDir( wpu->getBaseDir() );
               ec->addCommand( "%s", res_str.c_str() );
               tstr2 = ec->getOutput( &exeerror );
