@@ -100,7 +100,7 @@ ScrollListerOp::save(Datei *fh)
 const char *
 ScrollListerOp::getDescription()
 {
-  return catalog.getLocaleCom(35);
+  return catalog.getLocale(1276);
 }
 
 void
@@ -138,8 +138,8 @@ ScrollListerOp::configure()
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
   
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(35))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(35));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
