@@ -1,6 +1,6 @@
 /* searchentryop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2009,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2009,2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -54,7 +54,7 @@ protected:
   // temp variables
   Lister *startlister;
   
-  int normalmodesearchentry();
+    int vdm_searchentry();
 };
 
 #endif
