@@ -757,7 +757,7 @@ void SearchOpBG::editFile( const std::string &filename, int line_number )
   
     std::string exestr = rpl.replaceFlags( m_edit_command );
 
-    std::unique_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL ) );
+    std::unique_ptr<ExeClass> ec( new ExeClass() );
 
     ec->cdDir( fse.getDirname().c_str() );
     ec->addCommand( "%s", exestr.c_str() );
@@ -766,32 +766,34 @@ void SearchOpBG::editFile( const std::string &filename, int line_number )
 
 void SearchOpBG::initColorDefs()
 {
-    dircol.setFG( FieldListView::CC_NORMAL, wconfig->getUnselDir( 0 ) );
-    dircol.setBG( FieldListView::CC_NORMAL, wconfig->getUnselDir( 1 ) );
-    dircol.setFG( FieldListView::CC_SELECT, wconfig->getSelDir( 0 ) );
-    dircol.setBG( FieldListView::CC_SELECT, wconfig->getSelDir( 1 ) );
-    dircol.setFG( FieldListView::CC_ACTIVE, wconfig->getUnselDirAct( 0 ) );
-    dircol.setBG( FieldListView::CC_ACTIVE, wconfig->getUnselDirAct( 1 ) );
-    dircol.setFG( FieldListView::CC_SELACT, wconfig->getSelDirAct( 0 ) );
-    dircol.setBG( FieldListView::CC_SELACT, wconfig->getSelDirAct( 1 ) );
-  
-    filecol.setFG( FieldListView::CC_NORMAL, wconfig->getUnselFile( 0 ) );
-    filecol.setBG( FieldListView::CC_NORMAL, wconfig->getUnselFile( 1 ) );
-    filecol.setFG( FieldListView::CC_SELECT, wconfig->getSelFile( 0 ) );
-    filecol.setBG( FieldListView::CC_SELECT, wconfig->getSelFile( 1 ) );
-    filecol.setFG( FieldListView::CC_ACTIVE, wconfig->getUnselFileAct( 0 ) );
-    filecol.setBG( FieldListView::CC_ACTIVE, wconfig->getUnselFileAct( 1 ) );
-    filecol.setFG( FieldListView::CC_SELACT, wconfig->getSelFileAct( 0 ) );
-    filecol.setBG( FieldListView::CC_SELACT, wconfig->getSelFileAct( 1 ) );
+    AGUIX *aguix = Worker::getAGUIX();
 
-    resultcol.setFG( FieldListView::CC_NORMAL, wconfig->getUnselFile( 0 ) );
-    resultcol.setBG( FieldListView::CC_NORMAL, wconfig->getUnselFile( 1 ) );
-    resultcol.setFG( FieldListView::CC_SELECT, wconfig->getUnselFile( 0 ) );
-    resultcol.setBG( FieldListView::CC_SELECT, wconfig->getUnselFile( 1 ) );
-    resultcol.setFG( FieldListView::CC_ACTIVE, wconfig->getUnselFileAct( 0 ) );
-    resultcol.setBG( FieldListView::CC_ACTIVE, wconfig->getUnselFileAct( 1 ) );
-    resultcol.setFG( FieldListView::CC_SELACT, wconfig->getUnselFileAct( 0 ) );
-    resultcol.setBG( FieldListView::CC_SELACT, wconfig->getUnselFileAct( 1 ) );
+    dircol.setFG( FieldListView::CC_NORMAL, aguix->getFaces().getColor( "dirview-dir-normal-fg" ) );
+    dircol.setBG( FieldListView::CC_NORMAL, aguix->getFaces().getColor( "dirview-dir-normal-bg" ) );
+    dircol.setFG( FieldListView::CC_SELECT, aguix->getFaces().getColor( "dirview-dir-select-fg" ) );
+    dircol.setBG( FieldListView::CC_SELECT, aguix->getFaces().getColor( "dirview-dir-select-bg" ) );
+    dircol.setFG( FieldListView::CC_ACTIVE, aguix->getFaces().getColor( "dirview-dir-active-fg" ) );
+    dircol.setBG( FieldListView::CC_ACTIVE, aguix->getFaces().getColor( "dirview-dir-active-bg" ) );
+    dircol.setFG( FieldListView::CC_SELACT, aguix->getFaces().getColor( "dirview-dir-selact-fg" ) );
+    dircol.setBG( FieldListView::CC_SELACT, aguix->getFaces().getColor( "dirview-dir-selact-bg" ) );
+  
+    filecol.setFG( FieldListView::CC_NORMAL, aguix->getFaces().getColor( "dirview-file-normal-fg" ) );
+    filecol.setBG( FieldListView::CC_NORMAL, aguix->getFaces().getColor( "dirview-file-normal-bg" ) );
+    filecol.setFG( FieldListView::CC_SELECT, aguix->getFaces().getColor( "dirview-file-select-fg" ) );
+    filecol.setBG( FieldListView::CC_SELECT, aguix->getFaces().getColor( "dirview-file-select-bg" ) );
+    filecol.setFG( FieldListView::CC_ACTIVE, aguix->getFaces().getColor( "dirview-file-active-fg" ) );
+    filecol.setBG( FieldListView::CC_ACTIVE, aguix->getFaces().getColor( "dirview-file-active-bg" ) );
+    filecol.setFG( FieldListView::CC_SELACT, aguix->getFaces().getColor( "dirview-file-selact-fg" ) );
+    filecol.setBG( FieldListView::CC_SELACT, aguix->getFaces().getColor( "dirview-file-selact-bg" ) );
+
+    resultcol.setFG( FieldListView::CC_NORMAL, aguix->getFaces().getColor( "dirview-file-normal-fg" ) );
+    resultcol.setBG( FieldListView::CC_NORMAL, aguix->getFaces().getColor( "dirview-file-normal-bg" ) );
+    resultcol.setFG( FieldListView::CC_SELECT, aguix->getFaces().getColor( "dirview-file-normal-fg" ) );
+    resultcol.setBG( FieldListView::CC_SELECT, aguix->getFaces().getColor( "dirview-file-normal-bg" ) );
+    resultcol.setFG( FieldListView::CC_ACTIVE, aguix->getFaces().getColor( "dirview-file-active-fg" ) );
+    resultcol.setBG( FieldListView::CC_ACTIVE, aguix->getFaces().getColor( "dirview-file-active-bg" ) );
+    resultcol.setFG( FieldListView::CC_SELACT, aguix->getFaces().getColor( "dirview-file-active-fg" ) );
+    resultcol.setBG( FieldListView::CC_SELACT, aguix->getFaces().getColor( "dirview-file-active-bg" ) );
 }
 
 SearchOpBG::SearchOpBG( Worker *worker ) :
@@ -1027,7 +1029,7 @@ void SearchOpBG::createWindow()
     _resultlv->setShowHeader( true );
     _resultlv->setAcceptFocus( true );
     _resultlv->setDisplayFocus( true );
-    _resultlv->setMBG( wconfig->getListerBG() );
+    _resultlv->setMBG( aguix->getFaces().getColor( "dirview-bg" ) );
 
     AContainer *ac1_4 = ac1_res->add( new AContainer( m_win, 2, 1 ), 0, 1 );
     ac1_4->setMinSpace( 0 );
@@ -1071,7 +1073,7 @@ void SearchOpBG::createWindow()
     _storelv->setShowHeader( true );
     _storelv->setAcceptFocus( true );
     _storelv->setDisplayFocus( true );
-    _storelv->setMBG( wconfig->getListerBG() );
+    _storelv->setMBG( aguix->getFaces().getColor( "dirview-bg" ) );
     _storelv->setGlobalFieldSpace( 5 );
 
     m_clearstoreb =(Button*)ac1_res_store->add( new Button( aguix, 0, 0, catalog.getLocale( 738 ), 0 ), 0, 2, AContainer::CO_INCW );
