@@ -219,7 +219,7 @@ SetFilterOp::save(Datei *fh)
 const char *
 SetFilterOp::getDescription()
 {
-  return catalog.getLocaleCom(41);
+  return catalog.getLocale(1282);
 }
 
 int
