@@ -65,6 +65,6 @@ ShortkeyFromListOp::run( WPUContext *wpu, ActionMessage *msg )
 const char *
 ShortkeyFromListOp::getDescription()
 {
-  return catalog.getLocaleCom(42);
+  return catalog.getLocale(1283);
 }
 
