@@ -1,6 +1,6 @@
 /* showimagemode.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -48,9 +48,8 @@ public:
   virtual void cyclicfunc(cyclicfunc_mode_t mode);
   virtual const char* getLocaleName();
   virtual int load();
-  virtual int loadBin(Datei*);
   virtual bool save(Datei *);
-  virtual void reconfig();
+  virtual void relayout();
 
   static const char *getStaticLocaleName();
   static const char *getStaticType();
