@@ -1,6 +1,6 @@
 /* startprogop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2019 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -221,8 +221,16 @@ StartProgOp::startprog( WPUContext *wpu, ActionMessage *am )
       } else {
           m_default_file_filetype = "";
       }
+
+      if ( tfe->filetype && tfe->filetype != wconfig->getunknowntype() ) {
+          m_default_file_unknown = false;
+      } else {
+          m_default_file_unknown = true;
+      }
+      m_default_file_mime_type = tfe->getMimeType();
   } else {
     default_file = "";
+    m_default_file_unknown = false;
   }
 
   std::unique_ptr< StartSettings > m1;
@@ -1254,6 +1262,32 @@ void StartProgOp::updateCompletionList( const std::string &base,
    auto jobj = AJSON::as_object( filetype_history );
 
    if ( jobj ) {
+       if ( m_default_file_unknown ) {
+           auto jmimetype = AJSON::as_object( jobj->get( "mimetype" ) );
+
+           if ( jmimetype ) {
+               auto jcommands = AJSON::as_array( jmimetype->get( m_default_file_mime_type ) );
+
+               if ( jcommands ) {
+                   for ( size_t pos = 0; pos < jcommands->size(); pos++ ) {
+                       auto jcommand = AJSON::as_object( jcommands->get( pos ) );
+
+                       if ( ! jcommand ) continue;
+
+                       auto jcmd = AJSON::as_string( jcommand->get( "command" ) );
+
+                       if ( ! jcmd ) continue;
+
+                       if ( AGUIXUtils::starts_with( jcmd->get_value(), base ) ) {
+                           m_current_completions.push_back( std::make_pair( MIMETYPE_COMPLETION,
+                                                                            jcmd->get_value() ) );
+                           commands_in_use.insert( jcmd->get_value() );
+                       }
+                   }
+               }
+           }
+       }
+
        auto jft = AJSON::as_object( jobj->get( "filetype" ) );
 
        if ( jft ) {
@@ -1270,9 +1304,11 @@ void StartProgOp::updateCompletionList( const std::string &base,
                    if ( ! jcmd ) continue;
 
                    if ( AGUIXUtils::starts_with( jcmd->get_value(), base ) ) {
-                       m_current_completions.push_back( std::make_pair( FILETYPE_COMPLETION,
-                                                                        jcmd->get_value() ) );
-                       commands_in_use.insert( jcmd->get_value() );
+                       if ( commands_in_use.count( jcmd->get_value() ) == 0 ) {
+                           m_current_completions.push_back( std::make_pair( FILETYPE_COMPLETION,
+                                                                            jcmd->get_value() ) );
+                           commands_in_use.insert( jcmd->get_value() );
+                       }
                    }
                }
            }
@@ -1318,6 +1354,10 @@ void StartProgOp::updateSGFromComplete( StringGadget *sg,
 
         if ( s.first == FILETYPE_COMPLETION ) {
             lv->setText( row, 1, catalog.getLocale( 1321 ) );
+        } else if ( s.first == MIMETYPE_COMPLETION ) {
+            std::string info =AGUIXUtils::formatStringToString( catalog.getLocale( 1341 ),
+                                                                m_default_file_mime_type.c_str() );
+            lv->setText( row, 1, info );
         } else {
             lv->setText( row, 1, catalog.getLocale( 1322 ) );
         }
@@ -1435,4 +1475,43 @@ void StartProgOp::updateFiletypeHistory( std::shared_ptr< AJSON::JSONType > &fil
     }
 
     jft->set( m_default_file_filetype, jnew_commands );
+
+    /**************
+     * mime types *
+     **************/
+    if ( m_default_file_unknown ) {
+        auto jmimetype = AJSON::as_object( jobj->get( "mimetype" ) );
+
+        if ( ! jmimetype ) {
+            jmimetype = AJSON::as_object( jobj->set( "mimetype", AJSON::make_object() ) );
+
+            if ( ! jmimetype ) return;
+        }
+
+        auto jold_commands = AJSON::as_array( jmimetype->get( m_default_file_mime_type ) );
+
+        auto jnew_commands = AJSON::make_array();
+
+        auto jnew_command = AJSON::make_object();
+        jnew_command->set( "command", AJSON::make_string( base ) );
+        jnew_commands->append( jnew_command );
+
+        if ( jold_commands ) {
+            for ( size_t pos = 0; pos < jold_commands->size(); pos++ ) {
+                auto jold_command = AJSON::as_object( jold_commands->get( pos ) );
+
+                if ( ! jold_command ) continue;
+
+                auto jcmd = AJSON::as_string( jold_command->get( "command" ) );
+
+                if ( ! jcmd ) continue;
+
+                if ( jcmd->get_value() == base ) continue;
+
+                jnew_commands->append( jold_command );
+            }
+        }
+
+        jmimetype->set( m_default_file_mime_type, jnew_commands );
+    }
 }
