@@ -1,6 +1,6 @@
 /* stringmatcher_flexiblematch.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2012-2013 Ralf Hoffmann.
+ * Copyright (C) 2012-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -62,7 +62,7 @@ StringMatcherFlexibleMatch &StringMatcherFlexibleMatch::operator=( const StringM
 
 bool StringMatcherFlexibleMatch::match( const std::string &str )
 {
-    if ( countNonMatchingBlocks( str, NULL ) >= 0 ) return true;
+    if ( countNonMatchingBlocks<false>( str, NULL ) >= 0 ) return true;
 
     return false;
 }
@@ -183,7 +183,26 @@ void StringMatcherFlexibleMatch::createLoweredCase()
                     my_tolower<char>() );
 }
 
-struct state_type {
+template <bool with_offsets> struct state_type {
+    int state_number;
+    int block_counter;
+    bool prev_was_hit;
+    int offsets; //dummy variable
+
+    state_type( int _state_number,
+                int _block_counter,
+                bool _prev_was_hit,
+                int _offsets,
+                size_t _offset,
+                size_t _length ) : state_number( _state_number ),
+                                   block_counter( _block_counter ),
+                                   prev_was_hit( _prev_was_hit ),
+                                   offsets( _offsets )
+    {
+    }
+};
+
+template <> struct state_type<true> {
     int state_number;
     int block_counter;
     bool prev_was_hit;
@@ -201,17 +220,6 @@ struct state_type {
         offsets = current_offsets;
         offsets.push_back( std::make_pair( _offset, _length ) );
     }
-
-    bool operator<( const state_type &rhs ) const
-    {
-        if ( state_number < rhs.state_number ) return true;
-        else if ( state_number == rhs.state_number &&
-                  block_counter < rhs.block_counter ) return true;
-        else if ( state_number == rhs.state_number &&
-                  block_counter == rhs.block_counter &&
-                  prev_was_hit < rhs.prev_was_hit ) return true;
-        return false;
-    }
 };
 
 static bool check_string( const char *s1, int l1,
@@ -231,14 +239,72 @@ static bool check_string( const char *s1, int l1,
     return false;
 }
 
-int StringMatcherFlexibleMatch::countNonMatchingBlocks( const std::string &str,
-                                                        std::vector< size_t > *return_segments )
+template <bool with_segments> void getSegments( const std::string &str,
+                                                const std::list< state_type<with_segments> > &current_states,
+                                                const int state_list_size,
+                                                const int min_block_couunt,
+                                                std::vector< size_t > *return_segments )
+{
+}
+
+template <> void getSegments<true>( const std::string &str,
+                                    const std::list< state_type<true> > &current_states,
+                                    const int state_list_size,
+                                    const int min_block_count,
+                                    std::vector< size_t > *return_segments )
+{
+    // now generate list of alternating segments similar to flexibleregex
+    for ( auto it1 = current_states.begin();
+          it1 != current_states.end();
+          it1++ ) {
+        if ( it1->state_number >= state_list_size ) {
+            if ( min_block_count == it1->block_counter &&
+                 it1->offsets.size() > 1 ) {
+                std::vector< size_t > res;
+                size_t last_o = 0;
+                size_t last_segment_start = it1->offsets[1].first;
+                size_t last_segment_end = it1->offsets[1].first + it1->offsets[1].second;
+
+                for ( int i = 2; i < (int)it1->offsets.size(); i++ ) {
+                    const size_t o = it1->offsets[i].first;
+
+                    if ( o == last_segment_end ) {
+                        // merge matches
+                        last_segment_end = o + it1->offsets[i].second;
+                    } else {
+                        res.push_back( last_segment_start - last_o );
+                        res.push_back( last_segment_end - last_segment_start );
+                        last_o = last_segment_end;
+
+                        last_segment_start = o;
+                        last_segment_end = o + it1->offsets[i].second;
+                    }
+                }
+
+                res.push_back( last_segment_start - last_o );
+                res.push_back( last_segment_end - last_segment_start );
+                last_o = last_segment_end;
+
+                if ( last_o <= str.length() ) {
+                    res.push_back( str.length() - last_o );
+                }
+
+                *return_segments = res;
+
+                break;
+            }
+        }
+    }
+}
+
+template <bool with_segments> int StringMatcherFlexibleMatch::countNonMatchingBlocks( const std::string &str,
+                                                                                      std::vector< size_t > *return_segments )
 {
     // int pushes=0;
     // int c= 0;
     // int e=0;
 
-    std::list< state_type > current_states;
+    std::list< state_type<with_segments> > current_states;
     std::vector< int > smallest_negative_block_count;
     const int state_list_size = (int)m_state_list.size();
 
@@ -249,7 +315,7 @@ int StringMatcherFlexibleMatch::countNonMatchingBlocks( const std::string &str,
         smallest_negative_block_count[j] = -2;
     }
 
-    current_states.push_back( state_type( 0, -1, false, {}, 0, 0 ) );
+    current_states.push_back( state_type<with_segments>( 0, -1, false, {}, 0, 0 ) );
 
     const char *search_str = str.c_str();
     const char *search_str_start = search_str;
@@ -263,30 +329,33 @@ int StringMatcherFlexibleMatch::countNonMatchingBlocks( const std::string &str,
             break;
         }
 
-        for ( std::list< state_type >::iterator it1 = current_states.begin();
+        for ( auto it1 = current_states.begin();
               it1 != current_states.end(); ) {
             if ( it1->state_number < state_list_size ) {
                 if ( min_accepted_block_count >= 0 &&
                      it1->block_counter >= min_accepted_block_count ) {
                     // there is already an accepted state for the same or smaller block count
                     // so remove this state completely
-                    std::list< state_type >::iterator next = it1;
+                    auto next = it1;
                     next++;
                     current_states.erase( it1 );
                     it1=next;
                     continue;
                 } else {
+                    bool hit = false;
                     if ( check_string( search_str, sl,
                                        m_state_list[it1->state_number].sub_string,
                                        m_state_list[it1->state_number].string_len,
                                        m_match_case_sensitive ) ) {
                         //pushes++;
-                        current_states.push_front( state_type( it1->state_number + 1,
-                                                               it1->prev_was_hit ? it1->block_counter : it1->block_counter + 1,
-                                                               true,
-                                                               it1->offsets,
-                                                               search_str - search_str_start,
-                                                               sl) );
+                        current_states.push_front( state_type<with_segments>( it1->state_number + 1,
+                                                                              it1->prev_was_hit ? it1->block_counter : it1->block_counter + 1,
+                                                                              true,
+                                                                              it1->offsets,
+                                                                              search_str - search_str_start,
+                                                                              sl) );
+
+                        hit = true;
                     }
                     bool was_true = it1->prev_was_hit;
 
@@ -299,7 +368,7 @@ int StringMatcherFlexibleMatch::countNonMatchingBlocks( const std::string &str,
                         // block count smaller than already seen
                         if ( was_true ) {
                             // state changed from true to false so remove the state
-                            std::list< state_type >::iterator next = it1;
+                            auto next = it1;
                             next++;
                             current_states.erase( it1 );
                             it1=next;
@@ -308,6 +377,16 @@ int StringMatcherFlexibleMatch::countNonMatchingBlocks( const std::string &str,
                         }
                     } else {
                         smallest_negative_block_count[it1->state_number] = it1->block_counter;
+
+                        if ( was_true && hit ) {
+                            // current iterator was a hit, but there is a new match directly after so remove the old one
+                            auto next = it1;
+                            next++;
+                            current_states.erase( it1 );
+                            it1=next;
+                            //c++;
+                            continue;
+                        }
                     }
                 }
             } else if ( it1->block_counter == 0 ) {
@@ -331,7 +410,7 @@ int StringMatcherFlexibleMatch::countNonMatchingBlocks( const std::string &str,
         if ( current_states.size() > 1 ) {
             for ( int i = 0; i < state_list_size; i++ ) {
                 int smallest_block_counter = -2;
-                for ( std::list< state_type >::iterator it1 = current_states.begin();
+                for ( auto it1 = current_states.begin();
                       it1 != current_states.end();
                       it1++ ) {
                     if ( it1->state_number == i &&
@@ -346,13 +425,13 @@ int StringMatcherFlexibleMatch::countNonMatchingBlocks( const std::string &str,
                 if ( smallest_block_counter >= -1 ) {
                     bool kept_one = false;
 
-                    for ( std::list< state_type >::iterator it1 = current_states.begin();
+                    for ( auto it1 = current_states.begin();
                           it1 != current_states.end(); ) {
                         if ( it1->state_number == i &&
                              it1->prev_was_hit == false ) {
                             if ( it1->block_counter > smallest_block_counter ||
                                  ( kept_one == true && it1->block_counter == smallest_block_counter ) ) {
-                                std::list< state_type >::iterator next_it = it1;
+                                auto next_it = it1;
                                 next_it++;
                             
                                 //e++;
@@ -379,7 +458,7 @@ int StringMatcherFlexibleMatch::countNonMatchingBlocks( const std::string &str,
 
     int min_block_count = -1;
 
-    for ( std::list< state_type >::iterator it1 = current_states.begin();
+    for ( auto it1 = current_states.begin();
           it1 != current_states.end();
           it1++ ) {
         if ( it1->state_number >= state_list_size ) {
@@ -390,53 +469,22 @@ int StringMatcherFlexibleMatch::countNonMatchingBlocks( const std::string &str,
     }
 
     if ( return_segments ) {
-        // now generate list of alternating segments similar to flexibleregex
-        for ( std::list< state_type >::iterator it1 = current_states.begin();
-              it1 != current_states.end();
-              it1++ ) {
-            if ( it1->state_number >= state_list_size ) {
-                if ( min_block_count == it1->block_counter &&
-                     it1->offsets.size() > 1 ) {
-                    std::vector< size_t > res;
-                    size_t last_o = 0;
-                    size_t last_segment_start = it1->offsets[1].first;
-                    size_t last_segment_end = it1->offsets[1].first + it1->offsets[1].second;
-
-                    for ( int i = 2; i < (int)it1->offsets.size(); i++ ) {
-                        const size_t o = it1->offsets[i].first;
-
-                        if ( o == last_segment_end ) {
-                            // merge matches
-                            last_segment_end = o + it1->offsets[i].second;
-                        } else {
-                            res.push_back( last_segment_start - last_o );
-                            res.push_back( last_segment_end - last_segment_start );
-                            last_o = last_segment_end;
-
-                            last_segment_start = o;
-                            last_segment_end = o + it1->offsets[i].second;
-                        }
-                    }
-
-                    res.push_back( last_segment_start - last_o );
-                    res.push_back( last_segment_end - last_segment_start );
-                    last_o = last_segment_end;
-
-                    if ( last_o <= str.length() ) {
-                        res.push_back( str.length() - last_o );
-                    }
-
-                    *return_segments = res;
-
-                    break;
-                }
-            }
-        }
+        getSegments<with_segments>( str,
+                                    current_states,
+                                    state_list_size,
+                                    min_block_count,
+                                    return_segments );
     }
 
     return min_block_count;
 }
 
+template int StringMatcherFlexibleMatch::countNonMatchingBlocks<true>( const std::string &str,
+                                                                       std::vector< size_t > *return_segments );
+template int StringMatcherFlexibleMatch::countNonMatchingBlocks<false>( const std::string &str,
+                                                                        std::vector< size_t > *return_segments );
+
+
 void StringMatcherFlexibleMatch::buildStateDescription()
 {
     const char *needle_str = m_match_string.c_str();
