@@ -81,7 +81,7 @@ TabProfilesOp::run( WPUContext *wpu, ActionMessage *msg )
 const char *
 TabProfilesOp::getDescription()
 {
-    return catalog.getLocaleCom( 67 );
+    return catalog.getLocale( 1308 );
 }
 
 std::vector< std::string > TabProfilesOp::getAvailableProfiles()
