@@ -1,6 +1,6 @@
 /* textstoragefile.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2007,2011 Ralf Hoffmann.
+ * Copyright (C) 2005-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,7 +27,10 @@
 class TextStorageFile : public TextStorage
 {
  public:
-  TextStorageFile( const std::string &filename, const RefCount<AWidth> &lencalc, int initial_size = 0 );
+  TextStorageFile( const std::string &filename,
+                   const RefCount<AWidth> &lencalc,
+                   int initial_size,
+                   enum TextStorageString::text_storage_converion convert );
   int getNrOfLines() const;
   int getLine( int line_nr, unsigned int offset, int len, std::string &return_line ) const;
   int getLine( int line_nr, unsigned int offset, std::string &return_line ) const;
@@ -47,14 +50,24 @@ class TextStorageFile : public TextStorage
   int getUnwrappedLine( int line_nr,
                         unsigned int offset,
                         std::string &return_line ) const;
+  int getUnwrappedLineRaw( int line_nr,
+                           unsigned int offset,
+                           int len,
+                           std::string &return_line ) const;
+  int getUnwrappedLineRaw( int line_nr,
+                           unsigned int offset,
+                           std::string &return_line ) const;
   std::pair< std::pair< int, int >, int > getLineForOffset( int unwrapped_line_nr, int line_offset ) const;
 
   void readMore( int size = 0 );
+  void reloadFile();
   bool incompleteFile();
 
     void setFileName( const std::string &filename, int initial_size = 0 );
     int getCurrentSize() const;
- private:
+
+    void setConvertMode( enum TextStorageString::text_storage_converion convert );
+private:
   TextStorageString m_tss;
 
   std::string m_filename;
@@ -63,6 +76,7 @@ class TextStorageFile : public TextStorage
 
   bool m_incomplete_file;
   int m_file_size;
+  enum TextStorageString::text_storage_converion m_convert;
 
   void readFile();
 };
