@@ -100,7 +100,7 @@ ToggleListermodeOp::save(Datei *fh)
 const char *
 ToggleListermodeOp::getDescription()
 {
-  return catalog.getLocaleCom(39);
+  return catalog.getLocale(1280);
 }
 
 int
@@ -123,8 +123,8 @@ ToggleListermodeOp::configure()
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
   
-  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(39))+1);
-  sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(39));
+  tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
+  sprintf(tstr,catalog.getLocale(293),getDescription());
   win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
