@@ -435,6 +435,10 @@ void VirtualDirMode::finalizeCopy( std::shared_ptr< CopyState > cs )
 
                                              cs->m_row_adjustment++;
 
+                                             if ( ce->isRealDir() ) {
+                                                 ce->updateActiveForRemoval( std::get< 0 > ( *iti2 ) );
+                                             }
+
                                              iti2++;
                                          }
                                      } );
@@ -606,6 +610,10 @@ void VirtualDirMode::process_bg_messages()
 
                                 cs->m_row_adjustment++;
 
+                                if ( ce->isRealDir() ) {
+                                    ce->updateActiveForRemoval( msg.m_id );
+                                }
+
                                 if ( cs->m_insert_elements_into_vdm && ! msg.m_target_fullname.empty() ) {
                                     cs->m_inserts.push_back( msg.m_target_fullname );
                                 }
