@@ -190,6 +190,10 @@ void VirtualDirMode::deletef( struct deleteorder *delorder )
                                                showCacheState();
 
                                                row_adjustment++;
+
+                                               if ( ce->isRealDir() ) {
+                                                   ce->updateActiveForRemoval( id );
+                                               }
                                            } else if ( res == DeleteCore::NM_DELETE_SKIP ) {
                                            } else if ( res == DeleteCore::NM_DELETE_CANCEL ) {
                                                dc->setCancel( true );
