@@ -1,6 +1,6 @@
 /* wcfiletype.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2015 Ralf Hoffmann.
+ * Copyright (C) 2006-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -190,6 +190,13 @@ void WCFiletype::setName(const char *nname)
   } else {
     name=dupstring(nname);
   }
+
+  m_name_contains_flags = false;
+  if ( name ) {
+      if ( strchr( name, '{' ) != NULL ) {
+          m_name_contains_flags = true;
+      }
+  }
 }
 
 void WCFiletype::setPattern(const char *npattern)
@@ -1077,3 +1084,8 @@ void WCFiletype::splitPattern()
                                   ',' );
     }
 }
+
+bool WCFiletype::nameContainsFlags() const
+{
+    return m_name_contains_flags;
+}
