@@ -1,6 +1,6 @@
 /* wconfig.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2019 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,6 +31,7 @@
 #include <aguix/aguix.h>
 #include "stringcomparator.hh"
 #include "wconfig_types.hh"
+#include "wconfig_initial_command.hh"
 
 class Worker;
 class WCPath;
@@ -195,7 +196,7 @@ public:
   bool configureButtonIndex( int index );
   bool configurePathIndex( int index );
   bool configureHotkeyIndex( int index );
-  bool configureFiletype(WCFiletype*);
+  bool configureFiletype(WCFiletype*, int default_panel = 0);
 
   static bool isCorrectTerminalBin(const char*);
   int loadImportConfig( const char *filename,
@@ -346,6 +347,8 @@ public:
 
     void setDirectoryPresets( const std::map< std::string, struct directory_presets > &presets );
     const std::map< std::string, struct directory_presets > &getDirectoryPresets() const;
+
+    void setInitialCommand( const WConfigInitialCommand &cmd );
 protected:
   char *lang;
   unsigned int rows,columns;
@@ -441,6 +444,7 @@ protected:
                           bool &import_hotkeys,
                           bool &import_filetypes,
                           const std::string &info_text );
+  void insertFileTypeFlag( StringGadget *sg, WCFiletype *ft );
   
   int date_format;  // -1 = user-defined
                     // >=0 any of the predefined
@@ -500,6 +504,8 @@ protected:
     bool m_terminal_returns_early;
 
     std::map< std::string, struct directory_presets > m_directory_presets;
+
+    WConfigInitialCommand m_initial_command;
 };
 
 extern WConfig *wconfig;
