@@ -119,8 +119,8 @@ int BookmarkColorPanel::create()
     m_lv->setVBarState(0);
     m_lv->setShowHeader( true );
     m_lv->setFieldText( 0, catalog.getLocale( 555 ) );
-    m_lv->setHeaderFG( _baseconfig.getLVHeader( 0 ) );
-    m_lv->setHeaderBG( _baseconfig.getLVHeader( 1 ) );
+    m_lv->setHeaderFG( _baseconfig.getFaceDB().getColor( "dirview-header-fg" ) );
+    m_lv->setHeaderBG( _baseconfig.getFaceDB().getColor( "dirview-header-bg" ) );
 
     trow = m_lv->addRow();
     m_lv->setText( trow, 0, catalog.getLocale( 607 ) );
