@@ -93,8 +93,8 @@ int ColorPanel::create()
   ac1_1->setMaxSpace( 5 );
 
   sbsb = (SolidButton*)ac1_1->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 31 ),
-                                                    _baseconfig.getStatusbar( 0 ),
-                                                    _baseconfig.getStatusbar( 1 ),
+                                                    _aguix->getFaces().getColor( "statusbar-fg" ),
+                                                    _aguix->getFaces().getColor( "statusbar-bg" ),
                                                     false ), 0, 0, AContainer::CO_INCW );
   sbvb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                               1, 0, AContainer::CO_FIX );
@@ -111,8 +111,8 @@ int ColorPanel::create()
   ac1_2->setMaxSpace( 5 );
 
   slvbsb = (SolidButton*)ac1_2->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 34 ),
-                                                      _baseconfig.getSelLVB( 0 ),
-                                                      _baseconfig.getSelLVB( 1 ), false ),
+                                                      _baseconfig.getFaceDB().getColor( "lvb-active-fg" ),
+                                                      _baseconfig.getFaceDB().getColor( "lvb-active-bg" ), false ),
                                      0, 0, AContainer::CO_INCW );
   slvbvb = (Button*)ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                                 1, 0, AContainer::CO_FIX );
@@ -127,8 +127,8 @@ int ColorPanel::create()
   ac1_3->setMaxSpace( 5 );
 
   ulvbsb = (SolidButton*)ac1_3->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 35 ),
-                                                      _baseconfig.getUnselLVB( 0),
-                                                      _baseconfig.getUnselLVB( 1 ), false ),
+                                                      _baseconfig.getFaceDB().getColor( "lvb-inactive-fg" ),
+                                                      _baseconfig.getFaceDB().getColor( "lvb-inactive-bg" ), false ),
                                      0, 0, AContainer::CO_INCW );
   ulvbvb = (Button*)ac1_3->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                                 1, 0, AContainer::CO_FIX );
@@ -151,59 +151,59 @@ int ColorPanel::create()
   lv->setVBarState(0);
   lv->setShowHeader( true );
   lv->setFieldText( 0, catalog.getLocale( 555 ) );
-  lv->setHeaderFG( _baseconfig.getLVHeader( 0 ) );
-  lv->setHeaderBG( _baseconfig.getLVHeader( 1 ) );
+  lv->setHeaderFG( _baseconfig.getFaceDB().getColor( "dirview-header-fg" ) );
+  lv->setHeaderBG( _baseconfig.getFaceDB().getColor( "dirview-header-bg" ) );
 
-  fg = _baseconfig.getUnselDir( 0 );
-  bg = _baseconfig.getUnselDir( 1 );
+  fg = _baseconfig.getFaceDB().getColor( "dirview-dir-normal-fg" );
+  bg = _baseconfig.getFaceDB().getColor( "dirview-dir-normal-bg" );
   trow = lv->addRow();
   lv->setText( trow, 0, catalog.getLocale( 36 ) );
   setLVColors( trow, fg, bg );
 
-  fg = _baseconfig.getSelDir( 0 );
-  bg = _baseconfig.getSelDir( 1 );
+  fg = _baseconfig.getFaceDB().getColor( "dirview-dir-select-fg" );
+  bg = _baseconfig.getFaceDB().getColor( "dirview-dir-select-bg" );
   trow = lv->addRow();
   lv->setText( trow, 0, catalog.getLocale( 37 ) );
   setLVColors( trow, fg, bg );
 
-  fg = _baseconfig.getUnselFile( 0 );
-  bg = _baseconfig.getUnselFile( 1 );
+  fg = _baseconfig.getFaceDB().getColor( "dirview-file-normal-fg" );
+  bg = _baseconfig.getFaceDB().getColor( "dirview-file-normal-bg" );
   trow = lv->addRow();
   lv->setText( trow, 0, catalog.getLocale( 38 ) );
   setLVColors( trow, fg, bg );
 
-  fg = _baseconfig.getSelFile( 0 );
-  bg = _baseconfig.getSelFile( 1 );
+  fg = _baseconfig.getFaceDB().getColor( "dirview-file-select-fg" );
+  bg = _baseconfig.getFaceDB().getColor( "dirview-file-select-bg" );
   trow = lv->addRow();
   lv->setText( trow, 0, catalog.getLocale( 39 ) );
   setLVColors( trow, fg, bg );
 
-  fg = _baseconfig.getUnselDirAct( 0 );
-  bg = _baseconfig.getUnselDirAct( 1 );
+  fg = _baseconfig.getFaceDB().getColor( "dirview-dir-active-fg" );
+  bg = _baseconfig.getFaceDB().getColor( "dirview-dir-active-bg" );
   trow = lv->addRow();
   lv->setText( trow, 0, catalog.getLocale( 375 ) );
   setLVColors( trow, fg, bg );
 
-  fg = _baseconfig.getSelDirAct( 0 );
-  bg = _baseconfig.getSelDirAct( 1 );
+  fg = _baseconfig.getFaceDB().getColor( "dirview-dir-selact-fg" );
+  bg = _baseconfig.getFaceDB().getColor( "dirview-dir-selact-bg" );
   trow = lv->addRow();
   lv->setText( trow, 0, catalog.getLocale( 376 ) );
   setLVColors( trow, fg, bg );
 
-  fg = _baseconfig.getUnselFileAct( 0 );
-  bg = _baseconfig.getUnselFileAct( 1 );
+  fg = _baseconfig.getFaceDB().getColor( "dirview-file-active-fg" );
+  bg = _baseconfig.getFaceDB().getColor( "dirview-file-active-bg" );
   trow = lv->addRow();
   lv->setText( trow, 0, catalog.getLocale( 377 ) );
   setLVColors( trow, fg, bg );
 
-  fg = _baseconfig.getSelFileAct( 0 );
-  bg = _baseconfig.getSelFileAct( 1 );
+  fg = _baseconfig.getFaceDB().getColor( "dirview-file-selact-fg" );
+  bg = _baseconfig.getFaceDB().getColor( "dirview-file-selact-bg" );
   trow = lv->addRow();
   lv->setText( trow, 0, catalog.getLocale( 378 ) );
   setLVColors( trow, fg, bg );
 
   fg=1;
-  bg = _baseconfig.getListerBG();
+  bg = _baseconfig.getFaceDB().getColor( "dirview-bg" );
   trow = lv->addRow();
   lv->setText( trow, 0, catalog.getLocale( 379 ) );
   setLVColors( trow, fg, bg );
@@ -264,8 +264,8 @@ int ColorPanel::create()
   ac1_5->setMaxSpace( 5 );
 
   cbsb = (SolidButton*)ac1_5->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 43 ),
-                                                    _baseconfig.getClockbar( 0 ),
-                                                    _baseconfig.getClockbar( 1 ), false ),
+                                                    _baseconfig.getFaceDB().getColor( "clockbar-fg" ),
+                                                    _baseconfig.getFaceDB().getColor( "clockbar-bg" ), false ),
                                    0, 0, AContainer::CO_INCW );
   cbvb = (Button*)ac1_5->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                               1, 0, AContainer::CO_FIX );
@@ -282,8 +282,8 @@ int ColorPanel::create()
   ac1_6->setMaxSpace( 5 );
 
   rsb = (SolidButton*)ac1_6->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 44 ),
-                                                   _baseconfig.getRequest( 0 ),
-                                                   _baseconfig.getRequest( 1 ), false ),
+                                                   _baseconfig.getFaceDB().getColor( "request-fg" ),
+                                                   _baseconfig.getFaceDB().getColor( "request-bg" ), false ),
                                   0, 0, AContainer::CO_INCW );
   rvb = (Button*)ac1_6->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                              1, 0, AContainer::CO_FIX );
@@ -352,36 +352,6 @@ int ColorPanel::create()
 
 int ColorPanel::saveValues()
 {
-  _baseconfig.setStatusbar( 0, tempconfig->getStatusbar(0) );
-  _baseconfig.setStatusbar( 1, tempconfig->getStatusbar(1) );
-  _baseconfig.setSelLVB( 0, tempconfig->getSelLVB(0) );
-  _baseconfig.setSelLVB( 1, tempconfig->getSelLVB(1) );
-  _baseconfig.setUnselLVB( 0, tempconfig->getUnselLVB(0) );
-  _baseconfig.setUnselLVB( 1, tempconfig->getUnselLVB(1) );
-  _baseconfig.setSelDir( 0, tempconfig->getSelDir(0) );
-  _baseconfig.setSelDir( 1, tempconfig->getSelDir(1) );
-  _baseconfig.setUnselDir( 0, tempconfig->getUnselDir(0) );
-  _baseconfig.setUnselDir( 1, tempconfig->getUnselDir(1) );
-  _baseconfig.setSelFile( 0, tempconfig->getSelFile(0) );
-  _baseconfig.setSelFile( 1, tempconfig->getSelFile(1) );
-  _baseconfig.setUnselFile( 0, tempconfig->getUnselFile(0) );
-  _baseconfig.setUnselFile( 1, tempconfig->getUnselFile(1) );
-  _baseconfig.setSelDirAct( 0, tempconfig->getSelDirAct(0) );
-  _baseconfig.setSelDirAct( 1, tempconfig->getSelDirAct(1) );
-  _baseconfig.setUnselDirAct( 0, tempconfig->getUnselDirAct(0) );
-  _baseconfig.setUnselDirAct( 1, tempconfig->getUnselDirAct(1) );
-  _baseconfig.setSelFileAct( 0, tempconfig->getSelFileAct(0) );
-  _baseconfig.setSelFileAct( 1, tempconfig->getSelFileAct(1) );
-  _baseconfig.setUnselFileAct( 0, tempconfig->getUnselFileAct(0) );
-  _baseconfig.setUnselFileAct( 1, tempconfig->getUnselFileAct(1) );
-  _baseconfig.setClockbar( 0, tempconfig->getClockbar(0) );
-  _baseconfig.setClockbar( 1, tempconfig->getClockbar(1) );
-  _baseconfig.setRequest( 0, tempconfig->getRequest(0) );
-  _baseconfig.setRequest( 1, tempconfig->getRequest(1) );
-  _baseconfig.setLVHeader( 0, tempconfig->getLVHeader( 0 ) );
-  _baseconfig.setLVHeader( 1, tempconfig->getLVHeader( 1 ) );
-  _baseconfig.setListerBG( tempconfig->getListerBG() );
-
   _baseconfig.setFaceDB( *m_facedb_copy );
   return 0;
 }
@@ -394,71 +364,44 @@ WConfigPanel::panel_action_t ColorPanel::setColors( List *colors )
   return PANEL_NOACTION;
 }
 
+WConfigPanel::panel_action_t ColorPanel::setFaceDB( const FaceDB &faces )
+{
+    delete m_facedb_copy;
+    m_facedb_copy = new FaceDB( faces );
+    m_faces_lv->setSize( 0 );
+    prepareFaceLV();
+    m_faces_lv->redraw();
+
+    for ( auto &name : m_facedb_copy->getListOfFaces() ) {
+        applyFaceChange( name );
+    }
+
+    return PANEL_NOACTION;
+}
+
 void ColorPanel::run( Widget *elem, AGMessage &msg )
 {
-  int col;
-  
   if(msg.type==AG_BUTTONCLICKED) {
     if(msg.button.button==sbvb) {
-      col = tempconfig->palette( tempconfig->getStatusbar( 0 ) );
-      if(col>=0) {
-        tempconfig->setStatusbar( 0, col );
-        sbsb->setFG(col);
-      }
+        selectColor( "statusbar-fg" );
     } else if(msg.button.button==sbhb) {
-      col=tempconfig->palette( tempconfig->getStatusbar( 1 ) );
-      if(col>=0) {
-        tempconfig->setStatusbar( 1, col );
-        sbsb->setBG(col);
-      }
+        selectColor( "statusbar-bg" );
     } else if(msg.button.button==slvbvb) {
-      col=tempconfig->palette( tempconfig->getSelLVB( 0 ) );
-      if(col>=0) {
-        tempconfig->setSelLVB( 0, col );
-        slvbsb->setFG(col);
-      }
+        selectColor( "lvb-active-fg" );
     } else if(msg.button.button==slvbhb) {
-      col=tempconfig->palette( tempconfig->getSelLVB( 1 ) );
-      if(col>=0) {
-        tempconfig->setSelLVB( 1, col );
-        slvbsb->setBG(col);
-      }
+        selectColor( "lvb-active-bg" );
     } else if(msg.button.button==ulvbvb) {
-      col=tempconfig->palette( tempconfig->getUnselLVB( 0 ) );
-      if(col>=0) {
-        tempconfig->setUnselLVB( 0, col );
-        ulvbsb->setFG(col);
-      }
+        selectColor( "lvb-inactive-fg" );
     } else if(msg.button.button==ulvbhb) {
-      col=tempconfig->palette( tempconfig->getUnselLVB( 1 ) );
-      if(col>=0) {
-        tempconfig->setUnselLVB( 1, col );
-        ulvbsb->setBG(col);
-      }
+        selectColor( "lvb-inactive-bg" );
     } else if(msg.button.button==cbvb) {
-      col=tempconfig->palette( tempconfig->getClockbar( 0 ) );
-      if(col>=0) {
-        tempconfig->setClockbar( 0, col );
-        cbsb->setFG(col);
-      }
+        selectColor( "clockbar-fg" );
     } else if(msg.button.button==cbhb) {
-      col=tempconfig->palette( tempconfig->getClockbar( 1 ) );
-      if(col>=0) {
-        tempconfig->setClockbar( 1, col );
-        cbsb->setBG(col);
-      }
+        selectColor( "clockbar-bg" );
     } else if(msg.button.button==rvb) {
-      col=tempconfig->palette( tempconfig->getRequest( 0 ) );
-      if(col>=0) {
-        tempconfig->setRequest( 0, col );
-        rsb->setFG(col);
-      }
+        selectColor( "request-fg" );
     } else if(msg.button.button==rhb) {
-      col=tempconfig->palette( tempconfig->getRequest( 1 ) );
-      if(col>=0) {
-        tempconfig->setRequest( 1, col );
-        rsb->setBG(col);
-      }
+        selectColor( "request-bg" );
     } else if ( msg.button.button == m_face_modify ) {
         modifyFace();
     } else if ( msg.button.button == m_face_unset ) {
@@ -470,194 +413,67 @@ void ColorPanel::run( Widget *elem, AGMessage &msg )
         if(msg.button.button==b[i][0]) {
           switch(i) {
             case 1:
-              col=tempconfig->palette( tempconfig->getSelDir( 0 ) );
-              if(col>=0) {
-                tempconfig->setSelDir(0,col);
-                lv->setFG( i, FieldListView::CC_NORMAL, col );
-                lv->setFG( i, FieldListView::CC_SELECT, col );
-                lv->setFG( i, FieldListView::CC_ACTIVE, col );
-                lv->setFG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-dir-select-fg" );
+                break;
             case 2:
-              col=tempconfig->palette( tempconfig->getUnselFile( 0 ) );
-              if(col>=0) {
-                tempconfig->setUnselFile(0,col);
-                lv->setFG( i, FieldListView::CC_NORMAL, col );
-                lv->setFG( i, FieldListView::CC_SELECT, col );
-                lv->setFG( i, FieldListView::CC_ACTIVE, col );
-                lv->setFG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-file-normal-fg" );
+                break;
             case 3:
-              col=tempconfig->palette( tempconfig->getSelFile( 0 ) );
-              if(col>=0) {
-                tempconfig->setSelFile(0,col);
-                lv->setFG( i, FieldListView::CC_NORMAL, col );
-                lv->setFG( i, FieldListView::CC_SELECT, col );
-                lv->setFG( i, FieldListView::CC_ACTIVE, col );
-                lv->setFG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-file-select-fg" );
+                break;
             case 4:
-              col=tempconfig->palette( tempconfig->getUnselDirAct( 0 ) );
-              if(col>=0) {
-                tempconfig->setUnselDirAct(0,col);
-                lv->setFG( i, FieldListView::CC_NORMAL, col );
-                lv->setFG( i, FieldListView::CC_SELECT, col );
-                lv->setFG( i, FieldListView::CC_ACTIVE, col );
-                lv->setFG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-dir-active-fg" );
+                break;
             case 5:
-              col=tempconfig->palette( tempconfig->getSelDirAct( 0 ) );
-              if(col>=0) {
-                tempconfig->setSelDirAct(0,col);
-                lv->setFG( i, FieldListView::CC_NORMAL, col );
-                lv->setFG( i, FieldListView::CC_SELECT, col );
-                lv->setFG( i, FieldListView::CC_ACTIVE, col );
-                lv->setFG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-dir-selact-fg" );
+                break;
             case 6:
-              col=tempconfig->palette( tempconfig->getUnselFileAct( 0 ) );
-              if(col>=0) {
-                tempconfig->setUnselFileAct(0,col);
-                lv->setFG( i, FieldListView::CC_NORMAL, col );
-                lv->setFG( i, FieldListView::CC_SELECT, col );
-                lv->setFG( i, FieldListView::CC_ACTIVE, col );
-                lv->setFG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-file-active-fg" );
+                break;
             case 7:
-              col=tempconfig->palette( tempconfig->getSelFileAct( 0 ) );
-              if(col>=0) {
-                tempconfig->setSelFileAct(0,col);
-                lv->setFG( i, FieldListView::CC_NORMAL, col );
-                lv->setFG( i, FieldListView::CC_SELECT, col );
-                lv->setFG( i, FieldListView::CC_ACTIVE, col );
-                lv->setFG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-file-selact-fg" );
+                break;
             case 8:
               break;
             case 9:
-              col = tempconfig->palette( tempconfig->getLVHeader( 0 ) );
-              if ( col >= 0 ) {
-                tempconfig->setLVHeader( 0, col );
-                lv->setHeaderFG( col );
-              }
-              break;
+                selectColor( "dirview-header-fg" );
+                break;
             default:
-              col=tempconfig->palette( tempconfig->getUnselDir( 0 ) );
-              if(col>=0) {
-                tempconfig->setUnselDir(0,col);
-                lv->setFG( i, FieldListView::CC_NORMAL, col );
-                lv->setFG( i, FieldListView::CC_SELECT, col );
-                lv->setFG( i, FieldListView::CC_ACTIVE, col );
-                lv->setFG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-dir-normal-fg" );
+                break;
           }
         } else if(msg.button.button==b[i][1]) {
           switch(i) {
             case 1:
-              col=tempconfig->palette( tempconfig->getSelDir( 1 ) );
-              if(col>=0) {
-                tempconfig->setSelDir(1,col);
-                lv->setBG( i, FieldListView::CC_NORMAL, col );
-                lv->setBG( i, FieldListView::CC_SELECT, col );
-                lv->setBG( i, FieldListView::CC_ACTIVE, col );
-                lv->setBG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-dir-select-bg" );
+                break;
             case 2:
-              col=tempconfig->palette( tempconfig->getUnselFile( 1 ) );
-              if(col>=0) {
-                tempconfig->setUnselFile(1,col);
-                lv->setBG( i, FieldListView::CC_NORMAL, col );
-                lv->setBG( i, FieldListView::CC_SELECT, col );
-                lv->setBG( i, FieldListView::CC_ACTIVE, col );
-                lv->setBG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-file-normal-bg" );
+                break;
             case 3:
-              col=tempconfig->palette( tempconfig->getSelFile( 1 ) );
-              if(col>=0) {
-                tempconfig->setSelFile(1,col);
-                lv->setBG( i, FieldListView::CC_NORMAL, col );
-                lv->setBG( i, FieldListView::CC_SELECT, col );
-                lv->setBG( i, FieldListView::CC_ACTIVE, col );
-                lv->setBG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-file-select-bg" );
+                break;
             case 4:
-              col=tempconfig->palette( tempconfig->getUnselDirAct( 1 ) );
-              if(col>=0) {
-                tempconfig->setUnselDirAct(1,col);
-                lv->setBG( i, FieldListView::CC_NORMAL, col );
-                lv->setBG( i, FieldListView::CC_SELECT, col );
-                lv->setBG( i, FieldListView::CC_ACTIVE, col );
-                lv->setBG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-dir-active-bg" );
+                break;
             case 5:
-              col=tempconfig->palette( tempconfig->getSelDirAct( 1 ) );
-              if(col>=0) {
-                tempconfig->setSelDirAct(1,col);
-                lv->setBG( i, FieldListView::CC_NORMAL, col );
-                lv->setBG( i, FieldListView::CC_SELECT, col );
-                lv->setBG( i, FieldListView::CC_ACTIVE, col );
-                lv->setBG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-dir-selact-bg" );
+                break;
             case 6:
-              col=tempconfig->palette( tempconfig->getUnselFileAct( 1 ) );
-              if(col>=0) {
-                tempconfig->setUnselFileAct(1,col);
-                lv->setBG( i, FieldListView::CC_NORMAL, col );
-                lv->setBG( i, FieldListView::CC_SELECT, col );
-                lv->setBG( i, FieldListView::CC_ACTIVE, col );
-                lv->setBG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-file-active-bg" );
+                break;
             case 7:
-              col=tempconfig->palette( tempconfig->getSelFileAct( 1 ) );
-              if(col>=0) {
-                tempconfig->setSelFileAct(1,col);
-                lv->setBG( i, FieldListView::CC_NORMAL, col );
-                lv->setBG( i, FieldListView::CC_SELECT, col );
-                lv->setBG( i, FieldListView::CC_ACTIVE, col );
-                lv->setBG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-file-selact-bg" );
+                break;
             case 8:
-              col=tempconfig->palette( tempconfig->getListerBG() );
-              if(col>=0) {
-                tempconfig->setListerBG( col );
-                lv->setBG( i, FieldListView::CC_NORMAL, col );
-                lv->setBG( i, FieldListView::CC_SELECT, col );
-                lv->setBG( i, FieldListView::CC_ACTIVE, col );
-                lv->setBG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-bg" );
+                break;
             case 9:
-              col = tempconfig->palette( tempconfig->getLVHeader( 1 ) );
-              if ( col >= 0 ) {
-                tempconfig->setLVHeader( 1, col );
-                lv->setHeaderBG( col );
-              }
-              break;
+                selectColor( "dirview-header-bg" );
+                break;
             default:
-              col=tempconfig->palette( tempconfig->getUnselDir( 1 ) );
-              if(col>=0) {
-                tempconfig->setUnselDir(1,col);
-                lv->setBG( i, FieldListView::CC_NORMAL, col );
-                lv->setBG( i, FieldListView::CC_SELECT, col );
-                lv->setBG( i, FieldListView::CC_ACTIVE, col );
-                lv->setBG( i, FieldListView::CC_SELACT, col );
-              }
-              break;
+                selectColor( "dirview-dir-normal-bg" );
+                break;
           }
         }
       }
@@ -720,7 +536,9 @@ void ColorPanel::modifyFace()
         m_faces_lv->setText( row, 1, AGUIXUtils::convertToString( f.getColor() ) );
 
         m_faces_lv->redraw();
-    }
+ 
+        applyFaceChange( m_faces_lv->getText( row, 0 ) );
+   }
 }
 
 void ColorPanel::unsetFace()
@@ -739,6 +557,8 @@ void ColorPanel::unsetFace()
     m_faces_lv->setText( row, 1, "unset" );
 
     m_faces_lv->redraw();
+
+    applyFaceChange( m_faces_lv->getText( row, 0 ) );
 }
 
 void ColorPanel::changeToDefaultFace()
@@ -762,4 +582,146 @@ void ColorPanel::changeToDefaultFace()
     }
 
     m_faces_lv->redraw();
+
+    applyFaceChange( m_faces_lv->getText( row, 0 ) );
+}
+
+void ColorPanel::adjustFaceLV( const std::string &name,
+                               int col )
+{
+    for ( int row = 0; row < m_faces_lv->getElements(); row++ ) {
+        if ( m_faces_lv->getText( row, 0 ) == name ) {
+            m_faces_lv->setText( row, 1, AGUIXUtils::convertToString( col ) );
+            break;
+        }
+    }
+    m_faces_lv->redraw();
+}
+
+void ColorPanel::applyFaceChange( const std::string &name )
+{
+    int col = m_facedb_copy->getColor( name );
+
+    if ( name == "statusbar-fg" ) {
+        sbsb->setFG( col );
+    } else if ( name == "statusbar-bg" ) {
+        sbsb->setBG( col );
+    } else if ( name == "lvb-active-fg" ) {
+        slvbsb->setFG( col );
+    } else if ( name == "lvb-active-bg" ) {
+        slvbsb->setBG( col );
+    } else if ( name == "lvb-inactive-fg" ) {
+        ulvbsb->setFG( col );
+    } else if ( name == "lvb-inactive-bg" ) {
+        ulvbsb->setBG( col );
+    } else if ( name == "clockbar-fg" ) {
+        cbsb->setFG( col );
+    } else if ( name == "clockbar-bg" ) {
+        cbsb->setBG( col );
+    } else if ( name == "request-fg" ) {
+        rsb->setFG( col );
+    } else if ( name == "request-bg" ) {
+        rsb->setBG( col );
+    } else if ( name == "dirview-dir-select-fg" ) {
+        lv->setFG( 1, FieldListView::CC_NORMAL, col );
+        lv->setFG( 1, FieldListView::CC_SELECT, col );
+        lv->setFG( 1, FieldListView::CC_ACTIVE, col );
+        lv->setFG( 1, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-dir-select-bg" ) {
+        lv->setBG( 1, FieldListView::CC_NORMAL, col );
+        lv->setBG( 1, FieldListView::CC_SELECT, col );
+        lv->setBG( 1, FieldListView::CC_ACTIVE, col );
+        lv->setBG( 1, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-dir-normal-fg" ) {
+        lv->setFG( 0, FieldListView::CC_NORMAL, col );
+        lv->setFG( 0, FieldListView::CC_SELECT, col );
+        lv->setFG( 0, FieldListView::CC_ACTIVE, col );
+        lv->setFG( 0, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-dir-normal-bg" ) {
+        lv->setBG( 0, FieldListView::CC_NORMAL, col );
+        lv->setBG( 0, FieldListView::CC_SELECT, col );
+        lv->setBG( 0, FieldListView::CC_ACTIVE, col );
+        lv->setBG( 0, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-file-select-fg" ) {
+        lv->setFG( 3, FieldListView::CC_NORMAL, col );
+        lv->setFG( 3, FieldListView::CC_SELECT, col );
+        lv->setFG( 3, FieldListView::CC_ACTIVE, col );
+        lv->setFG( 3, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-file-select-bg" ) {
+        lv->setBG( 3, FieldListView::CC_NORMAL, col );
+        lv->setBG( 3, FieldListView::CC_SELECT, col );
+        lv->setBG( 3, FieldListView::CC_ACTIVE, col );
+        lv->setBG( 3, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-file-normal-fg" ) {
+        lv->setFG( 2, FieldListView::CC_NORMAL, col );
+        lv->setFG( 2, FieldListView::CC_SELECT, col );
+        lv->setFG( 2, FieldListView::CC_ACTIVE, col );
+        lv->setFG( 2, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-file-normal-bg" ) {
+        lv->setBG( 2, FieldListView::CC_NORMAL, col );
+        lv->setBG( 2, FieldListView::CC_SELECT, col );
+        lv->setBG( 2, FieldListView::CC_ACTIVE, col );
+        lv->setBG( 2, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-dir-selact-fg" ) {
+        lv->setFG( 5, FieldListView::CC_NORMAL, col );
+        lv->setFG( 5, FieldListView::CC_SELECT, col );
+        lv->setFG( 5, FieldListView::CC_ACTIVE, col );
+        lv->setFG( 5, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-dir-selact-bg" ) {
+        lv->setBG( 5, FieldListView::CC_NORMAL, col );
+        lv->setBG( 5, FieldListView::CC_SELECT, col );
+        lv->setBG( 5, FieldListView::CC_ACTIVE, col );
+        lv->setBG( 5, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-dir-active-fg" ) {
+        lv->setFG( 4, FieldListView::CC_NORMAL, col );
+        lv->setFG( 4, FieldListView::CC_SELECT, col );
+        lv->setFG( 4, FieldListView::CC_ACTIVE, col );
+        lv->setFG( 4, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-dir-active-bg" ) {
+        lv->setBG( 4, FieldListView::CC_NORMAL, col );
+        lv->setBG( 4, FieldListView::CC_SELECT, col );
+        lv->setBG( 4, FieldListView::CC_ACTIVE, col );
+        lv->setBG( 4, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-file-selact-fg" ) {
+        lv->setFG( 7, FieldListView::CC_NORMAL, col );
+        lv->setFG( 7, FieldListView::CC_SELECT, col );
+        lv->setFG( 7, FieldListView::CC_ACTIVE, col );
+        lv->setFG( 7, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-file-selact-bg" ) {
+        lv->setBG( 7, FieldListView::CC_NORMAL, col );
+        lv->setBG( 7, FieldListView::CC_SELECT, col );
+        lv->setBG( 7, FieldListView::CC_ACTIVE, col );
+        lv->setBG( 7, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-file-active-fg" ) {
+        lv->setFG( 6, FieldListView::CC_NORMAL, col );
+        lv->setFG( 6, FieldListView::CC_SELECT, col );
+        lv->setFG( 6, FieldListView::CC_ACTIVE, col );
+        lv->setFG( 6, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-file-active-bg" ) {
+        lv->setBG( 6, FieldListView::CC_NORMAL, col );
+        lv->setBG( 6, FieldListView::CC_SELECT, col );
+        lv->setBG( 6, FieldListView::CC_ACTIVE, col );
+        lv->setBG( 6, FieldListView::CC_SELACT, col );
+    } else if ( name == "dirview-header-fg" ) {
+        lv->setHeaderFG( col );
+    } else if ( name == "dirview-header-bg" ) {
+        lv->setHeaderBG( col );
+    } else if ( name == "dirview-bg" ) {
+        lv->setBG( 8, FieldListView::CC_NORMAL, col );
+        lv->setBG( 8, FieldListView::CC_SELECT, col );
+        lv->setBG( 8, FieldListView::CC_ACTIVE, col );
+        lv->setBG( 8, FieldListView::CC_SELACT, col );
+    }
+
+    lv->redraw();
+}
+
+void ColorPanel::selectColor( const std::string &name )
+{
+    int col = tempconfig->palette( m_facedb_copy->getColor( name ) );
+    if ( col >= 0 ) {
+        m_facedb_copy->setColor( name, col );
+        adjustFaceLV( name, col );
+        applyFaceChange( name );
+    }
 }
