@@ -1,6 +1,6 @@
 /* wconfig_dcd.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006,2011-2012 Ralf Hoffmann.
+ * Copyright (C) 2006-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -67,18 +67,18 @@ int DCDPanel::create()
   ac1_1->setMaxSpace( 0 );
   ac1_1->setBorderWidth( 0 );
 
-  newb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 181 ), 1, 0, 0 ),
+  newb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 181 ), 0 ),
 			      0, 0, AContainer::CO_INCW );
   newb->connect( this );
-  delb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 183 ), 1, 0, 0 ),
+  delb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 183 ), 0 ),
 			      1, 0, AContainer::CO_INCW );
   delb->connect( this );
-  editb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 182 ), 1, 0, 0 ),
+  editb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 182 ), 0 ),
 			       2, 0, AContainer::CO_INCW );
   editb->connect( this );
 
   cb = (ChooseButton*)ac1->add( new ChooseButton( _aguix, 0, 0, _baseconfig.getDontCheckVirtual(),
-						  catalog.getLocale( 619 ), LABEL_RIGHT, 1, 0 ),
+						  catalog.getLocale( 619 ), LABEL_RIGHT, 0 ),
 				0, 3, AContainer::CO_INCWNR );
 
   contMaximize( true );
