@@ -59,8 +59,8 @@ int ListerPanel::create()
   ac2->setMaxSpace( 5 );
   ac2->setBorderWidth( 0 );
   
-  ac2->add( new Text( _aguix, 0, 0, catalog.getLocale( 19 ), 1 ), 0, 0, AContainer::CO_INCWNR );
-  ac2->add( new Text( _aguix, 0, 0, catalog.getLocale( 20 ), 1 ), 1, 0, AContainer::CO_INCWNR );
+  ac2->add( new Text( _aguix, 0, 0, catalog.getLocale( 19 ) ), 0, 0, AContainer::CO_INCWNR );
+  ac2->add( new Text( _aguix, 0, 0, catalog.getLocale( 20 ) ), 1, 0, AContainer::CO_INCWNR );
 
   AContainerBB *ac21 = (AContainerBB*)ac2->add( new AContainerBB( this, 1, 7 ), 0, 1 );
   AContainerBB *ac22 = (AContainerBB*)ac2->add( new AContainerBB( this, 1, 7 ), 1, 1 );
@@ -74,7 +74,7 @@ int ListerPanel::create()
                                                       100,
                                                       80,
                                                       0 ), 0, 0, cmwmh );
-  ac21->add( new Text( _aguix, 0, 0, catalog.getLocale( 21 ), 1 ), 0, 1, AContainer::CO_INCWNR );
+  ac21->add( new Text( _aguix, 0, 0, catalog.getLocale( 21 ) ), 0, 1, AContainer::CO_INCWNR );
 
   AContainer *ac21a = ac21->add( new AContainer( this, 1, 2 ), 0, 2 );
   ac21a->setMaxSpace( 5 );
@@ -87,11 +87,10 @@ int ListerPanel::create()
                                                      ( _baseconfig.getHBarTop( 0 ) == true ) ? 1 : 0,
                                                      catalog.getLocale( 22 ),
                                                      LABEL_LEFT,
-                                                     1,
                                                      0 ), 0, 0, AContainer::CO_INCWNR );
   cb1->connect( this );
   AContainer *ac211 = ac21a->add( new AContainer( this, 2, 1 ), 0, 1 );
-  ac211->add( new Text( _aguix, 0, 0, catalog.getLocale( 23 ), 1 ), 0, 0, AContainer::CO_FIX );
+  ac211->add( new Text( _aguix, 0, 0, catalog.getLocale( 23 ) ), 0, 0, AContainer::CO_FIX );
   sprintf( tstr, "%d", (int)_baseconfig.getHBarHeight( 0 ) );
   sg1 = (StringGadget*)ac211->add( new StringGadget( _aguix,
                                                      0,
@@ -103,7 +102,7 @@ int ListerPanel::create()
   ac211->setBorderWidth( 0 );
   ac211->setMaxSpace( 5 );
 
-  ac21->add( new Text( _aguix, 0, 0, catalog.getLocale( 24 ), 1 ), 0, 3, AContainer::CO_INCWNR );
+  ac21->add( new Text( _aguix, 0, 0, catalog.getLocale( 24 ) ), 0, 3, AContainer::CO_INCWNR );
 
   AContainer *ac21b = ac21->add( new AContainer( this, 1, 2 ), 0, 4 );
   ac21b->setMaxSpace( 5 );
@@ -116,11 +115,10 @@ int ListerPanel::create()
                                                      ( _baseconfig.getVBarLeft( 0 ) == true ) ? 1 : 0,
                                                      catalog.getLocale( 25 ),
                                                      LABEL_LEFT,
-                                                     1,
                                                      0 ), 0, 0, AContainer::CO_INCWNR );
   cb2->connect( this );
   AContainer *ac212 = ac21b->add( new AContainer( this, 2, 1 ), 0, 1 );
-  ac212->add( new Text( _aguix, 0, 0, catalog.getLocale( 26 ), 1 ), 0, 0, AContainer::CO_FIX );
+  ac212->add( new Text( _aguix, 0, 0, catalog.getLocale( 26 ) ), 0, 0, AContainer::CO_FIX );
   sprintf( tstr, "%d", (int)_baseconfig.getVBarWidth( 0 ));
   sg2 = (StringGadget*)ac212->add( new StringGadget( _aguix,
                                                      0,
@@ -140,7 +138,6 @@ int ListerPanel::create()
                                                      ( _baseconfig.getShowHeader( 0 ) == true ) ? 1 : 0,
                                                      catalog.getLocale( 554 ),
                                                      LABEL_LEFT,
-                                                     1,
                                                      0 ), 0, 5, AContainer::CO_INCWNR );
   cb13->connect( this );
 
@@ -152,7 +149,6 @@ int ListerPanel::create()
                                                           ( _baseconfig.getPathEntryOnTop( 0 ) == true ) ? 1 : 0,
                                                           catalog.getLocale( 1041 ),
                                                           LABEL_LEFT,
-                                                          1,
                                                           0 ), 0, 6, AContainer::CO_INCWNR );
   m_left_path_top_cb->connect( this );
   
@@ -162,7 +158,7 @@ int ListerPanel::create()
                                                       100,
                                                       80,
                                                       0 ), 0, 0, cmwmh );
-  ac22->add( new Text( _aguix, 0, 0, catalog.getLocale( 21 ), 1 ), 0, 1, AContainer::CO_INCWNR );
+  ac22->add( new Text( _aguix, 0, 0, catalog.getLocale( 21 ) ), 0, 1, AContainer::CO_INCWNR );
 
   AContainer *ac22a = ac22->add( new AContainer( this, 1, 2 ), 0, 2 );
   ac22a->setMaxSpace( 5 );
@@ -175,11 +171,10 @@ int ListerPanel::create()
                                                      ( _baseconfig.getHBarTop( 1 ) == true ) ? 1 : 0,
                                                      catalog.getLocale( 22 ),
                                                      LABEL_LEFT,
-                                                     1,
                                                      0 ), 0, 0, AContainer::CO_INCWNR );
   cb3->connect( this );
   AContainer *ac221 = ac22a->add( new AContainer( this, 2, 1 ), 0, 1 );
-  ac221->add( new Text( _aguix, 0, 0, catalog.getLocale( 23 ), 1 ), 0, 0, AContainer::CO_FIX );
+  ac221->add( new Text( _aguix, 0, 0, catalog.getLocale( 23 ) ), 0, 0, AContainer::CO_FIX );
   sprintf( tstr, "%d", (int)_baseconfig.getHBarHeight( 1 ) );
   sg3 = (StringGadget*)ac221->add( new StringGadget( _aguix,
                                                      0,
@@ -191,7 +186,7 @@ int ListerPanel::create()
   ac221->setBorderWidth( 0 );
   ac221->setMaxSpace( 5 );
 
-  ac22->add( new Text( _aguix, 0, 0, catalog.getLocale( 24 ), 1 ), 0, 3, AContainer::CO_INCWNR );
+  ac22->add( new Text( _aguix, 0, 0, catalog.getLocale( 24 ) ), 0, 3, AContainer::CO_INCWNR );
 
   AContainer *ac22b = ac22->add( new AContainer( this, 1, 2 ), 0, 4 );
   ac22b->setMaxSpace( 5 );
@@ -204,11 +199,10 @@ int ListerPanel::create()
                                                      ( _baseconfig.getVBarLeft( 1 ) == true ) ? 1 : 0,
                                                      catalog.getLocale( 25 ),
                                                      LABEL_LEFT,
-                                                     1,
                                                      0 ), 0, 0, AContainer::CO_INCWNR );
   cb4->connect( this );
   AContainer *ac222 = ac22b->add( new AContainer( this, 2, 1 ), 0, 1 );
-  ac222->add( new Text( _aguix, 0, 0, catalog.getLocale( 26 ), 1 ), 0, 0, AContainer::CO_FIX );
+  ac222->add( new Text( _aguix, 0, 0, catalog.getLocale( 26 ) ), 0, 0, AContainer::CO_FIX );
   sprintf( tstr, "%d", (int)_baseconfig.getVBarWidth( 1 ) );
   sg4 = (StringGadget*)ac222->add( new StringGadget( _aguix,
                                                      0,
@@ -228,7 +222,6 @@ int ListerPanel::create()
                                                      ( _baseconfig.getShowHeader( 1 ) == true ) ? 1 : 0,
                                                      catalog.getLocale( 554 ),
                                                      LABEL_LEFT,
-                                                     1,
                                                      0 ), 0, 5, AContainer::CO_INCWNR );
   cb23->connect( this );
   
@@ -240,7 +233,6 @@ int ListerPanel::create()
                                                            ( _baseconfig.getPathEntryOnTop( 1 ) == true ) ? 1 : 0,
                                                            catalog.getLocale( 1041 ),
                                                            LABEL_LEFT,
-                                                           1,
                                                            0 ), 0, 6, AContainer::CO_INCWNR );
   m_right_path_top_cb->connect( this );
   
