@@ -35,9 +35,7 @@ MainUIPanel::~MainUIPanel()
 
 int MainUIPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   AContainer *ac1 = setContainer( new AContainer( this, 1, 1 ), true );
   ac1->setBorderWidth( 5 );
