@@ -1,6 +1,6 @@
 /* wconfig_termconf.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2014 Ralf Hoffmann.
+ * Copyright (C) 2006-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,7 @@
 #include "worker_locale.h"
 #include <aguix/button.h>
 #include <aguix/stringgadget.h>
+#include "aguix/choosebutton.h"
 
 TermConfPanel::TermConfPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
@@ -38,7 +39,7 @@ int TermConfPanel::create()
 {
   Panel::create();
 
-  AContainer *ac1 = setContainer( new AContainer( this, 1, 4 ), true );
+  AContainer *ac1 = setContainer( new AContainer( this, 1, 5 ), true );
   ac1->setBorderWidth( 5 );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
@@ -76,6 +77,11 @@ int TermConfPanel::create()
                                                    0 ),
                                        1, 0, AContainer::CO_FIX );
   defaultbutton->connect( this );
+
+  m_terminal_returns_early = ac1->addWidget( new ChooseButton( _aguix,
+                                                               0, 0, _baseconfig.getTerminalReturnsEarly(),
+                                                               catalog.getLocale( 1328 ), LABEL_RIGHT, 0 ),
+                                             0, 4, AContainer::CO_INCWNR );
   
   contMaximize( true );
   return 0;
@@ -84,6 +90,7 @@ int TermConfPanel::create()
 int TermConfPanel::saveValues()
 {
   _baseconfig.setTerminalBin( sg->getText() );
+  _baseconfig.setTerminalReturnsEarly( m_terminal_returns_early->getState() );
   return 0;
 }
 
