@@ -1,6 +1,6 @@
 /* worker.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2019 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -40,7 +40,8 @@
 #include "kvpstore.hh"
 #include <future>
 #include "worker_types.h"
-#include "pathjumpui_types.hh"
+#include "existence_test.hh"
+#include "wconfig_initial_command.hh"
 
 class ListerMode;
 class Lister;
@@ -171,6 +172,7 @@ public:
   static std::string getWorkerConfigDir();
 
   void openWorkerMenu();
+    void handleHelp();
 
   int getStatebarWidth();
 
@@ -255,7 +257,7 @@ public:
 
     static KVPStore &getKVPStore();
 
-    void enqueueFuture( std::future< PathJumpUITypes::existence_state_t > f );
+    void enqueueFuture( std::future< ExistenceTest::existence_state_t > f );
 
     std::list< WorkerTypes::reg_command_info_t > getListOfCommandsWithoutArgs() const;
     WorkerTypes::reg_command_info_t getCommandInfo( const std::string &command ) const;
@@ -265,6 +267,7 @@ public:
                                            bool &remove_after_exec );
 
     void issueConfigOpen( const std::string &panel );
+    void issueConfigOpen( const std::string &panel, const WConfigInitialCommand &cmd );
 protected:
   void createMainWin();
   void setupMainWin();
@@ -383,7 +386,10 @@ protected:
     void updateStatebar();
 
     TimedText m_key_message;
-    std::string getNamesOfKeyChainCompletions( KeySym k, unsigned int m );
+    std::string getNamesOfKeyChainCompletions( KeySym k, unsigned int m,
+                                               std::list< WCButton * > *buttons,
+                                               std::list< WCHotkey * > *hotkeys,
+                                               std::list< WCPath * > *paths );
 
     HWVolumeManager m_volume_manager;
     void checkNewVolumes();
@@ -456,6 +462,13 @@ protected:
     void cleanFutures();
     void checkFutures();
 
+    void disableHelp();
+    void showHelp( KeySym lastkey,
+                   unsigned int lastmod,
+                   const std::list< WCButton * > &button_list,
+                   const std::list< WCHotkey * > &hotkey_list,
+                   const std::list< WCPath * > &path_list );
+
     DeepPathStore m_path_store;
     std::unique_ptr< PersDeepPathStore > m_pers_path_store;
 
@@ -487,9 +500,13 @@ protected:
 
     TimedText m_button_help_text;
 
-    std::list< std::future< PathJumpUITypes::existence_state_t > > m_existence_futures;
+    std::list< std::future< ExistenceTest::existence_state_t > > m_existence_futures;
 
     std::string m_pending_config_open;
+    WConfigInitialCommand m_pending_config_command;
+
+    TimedText m_help_message;
+    bool m_help_active = false;
 };
 
 #endif
