@@ -1,6 +1,6 @@
 /* worker_commands.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2019 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,7 +25,7 @@
 
 int Worker::getNrOfCommands()
 {
-  return 57;
+  return 58;
 }
 
 FunctionProto *Worker::getCommand4ID(int id)
@@ -196,6 +196,9 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 56:
       fpr = new ModifyTabsOp();
       break;
+    case 57:
+      fpr = new HelpOp();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -262,6 +265,7 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( OpenWorkerMenuOp::name ) == true ) type = 54;
   else if ( fpr->isName( ChangeLabelOp::name ) == true ) type = 55;
   else if ( fpr->isName( ModifyTabsOp::name ) == true ) type = 56;
+  else if ( fpr->isName( HelpOp::name ) == true ) type = 57;
   return type;
 }
 
