@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2019 Ralf Hoffmann.
+ * Copyright (C) 2001-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,7 +27,7 @@
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 1341
+#define CATENTRY 1356
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -1442,6 +1442,21 @@ The default value here is the active entry and it's already correctly protected!
   catalog[1338]=dupstring( "Sort mode:" );
   catalog[1339]=dupstring( "Remove filter" );
   catalog[1340]=dupstring( "Enter directory for which separate sort and|filter settings should be applied to." );
+  catalog[1341]=dupstring( "(Mime type \"%s\" for unknown filetype)" );
+  catalog[1342]=dupstring( "Mime type" );
+  catalog[1343]=dupstring( "Create new filetype" );
+  catalog[1344]=dupstring( "Edit filetype" );
+  catalog[1345]=dupstring( "Toggle help state" );
+  catalog[1346]=dupstring( "Click button or press key to get help about assigned commands" );
+  catalog[1347]=dupstring( "Help about assigned commands" );
+  catalog[1348]=dupstring( "Assigned command for clicked element:" );
+  catalog[1349]=dupstring( "Assigned command for key (prefix) %s:" );
+  catalog[1350]=dupstring( "Element type" );
+  catalog[1351]=dupstring( "Short key" );
+  catalog[1352]=dupstring( "Assigned command" );
+  catalog[1353]=dupstring( "Button '%s'" );
+  catalog[1354]=dupstring( "Hotkey '%s'" );
+  catalog[1355]=dupstring( "Path button '%s'" );
 
 //  catalog[]=dupstring( "" );
   
