@@ -625,7 +625,10 @@ char *WPUContext::readBrace()
 
   len = endpos - startpos;
   tstr = (char*)_allocsafe( len + 1 );
-  strncpy( tstr, scanbuf + startpos, len );
+  if ( len > 0 ) {
+      strncpy( tstr, scanbuf + startpos, len );
+  }
+  tstr[len] = '\0';
   /* now turn backslashed {/} to normal {/} and remove first and last brace */
   t = 0; readpos = 1;
   for( readpos = 1; readpos < ( len - 1); readpos++ ) {
