@@ -1,6 +1,6 @@
 /* wpucontext.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2005,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2002-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -167,6 +167,8 @@ public:
 
   void ref();
   int unref();
+
+    const std::string &getPathDBFilename() const;
 private:
   WPUStack **stacks;
   ArrayList *acoms;
@@ -258,6 +260,7 @@ private:
   bool m_take_dirs;
   bool m_use_virtual_temp_copies;
   bool m_use_extended_basename;
+    std::string m_pathdb_filename;
 };
 
 #endif
